@@ -1,23 +1,29 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_CHUNKED_ARRAY_HPP
 #define XTENSOR_CHUNKED_ARRAY_HPP
 
-#include <vector>
 #include <array>
+#include <vector>
 
 #include "xarray.hpp"
 #include "xchunked_assign.hpp"
 
 namespace xt
 {
+    /**
+     * @defgroup xt_xchunked_array
+     *
+     * Chunked array container.
+     * Defined in ``xtensor/xchunked_array.hpp``.
+     */
 
     /******************************
      * xchunked_array declaration *
@@ -47,9 +53,9 @@ namespace xt
     };
 
     template <class chunk_storage>
-    class xchunked_array: public xaccessible<xchunked_array<chunk_storage>>,
-                          public xiterable<xchunked_array<chunk_storage>>,
-                          public xchunked_semantic<xchunked_array<chunk_storage>>
+    class xchunked_array : public xaccessible<xchunked_array<chunk_storage>>,
+                           public xiterable<xchunked_array<chunk_storage>>,
+                           public xchunked_semantic<xchunked_array<chunk_storage>>
     {
     public:
 
@@ -79,7 +85,12 @@ namespace xt
         using const_chunk_iterator = xchunk_iterator<const self_type>;
 
         template <class S>
-        xchunked_array(chunk_storage_type&& chunks, S&& shape, S&& chunk_shape, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+        xchunked_array(
+            chunk_storage_type&& chunks,
+            S&& shape,
+            S&& chunk_shape,
+            layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT
+        );
         ~xchunked_array() = default;
 
         xchunked_array(const xchunked_array&) = default;
@@ -89,10 +100,19 @@ namespace xt
         xchunked_array& operator=(xchunked_array&&) = default;
 
         template <class E>
-        xchunked_array(const xexpression<E>&e , chunk_storage_type&& chunks, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+        xchunked_array(
+            const xexpression<E>& e,
+            chunk_storage_type&& chunks,
+            layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT
+        );
 
         template <class E, class S>
-        xchunked_array(const xexpression<E>& e, chunk_storage_type&& chunks, S&& chunk_shape, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+        xchunked_array(
+            const xexpression<E>& e,
+            chunk_storage_type&& chunks,
+            S&& chunk_shape,
+            layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT
+        );
 
         template <class E>
         xchunked_array& operator=(const xexpression<E>& e);
@@ -148,7 +168,8 @@ namespace xt
     private:
 
         template <class... Idxs>
-        using indexes_type = std::pair<std::array<std::size_t, sizeof...(Idxs)>, std::array<std::size_t, sizeof...(Idxs)>>;
+        using indexes_type = std::
+            pair<std::array<std::size_t, sizeof...(Idxs)>, std::array<std::size_t, sizeof...(Idxs)>>;
 
         template <class... Idxs>
         using chunk_indexes_type = std::array<std::pair<std::size_t, std::size_t>, sizeof...(Idxs)>;
@@ -171,7 +192,7 @@ namespace xt
         chunk_indexes_type<Idxs...> get_chunk_indexes(std::index_sequence<dims...>, Idxs... idxs) const;
 
         template <class T, std::size_t N>
-        static_indexes_type<N> unpack(const std::array<T, N> &arr) const;
+        static_indexes_type<N> unpack(const std::array<T, N>& arr) const;
 
         template <class It>
         dynamic_indexes_type get_indexes_dynamic(It first, It last) const;
@@ -181,15 +202,18 @@ namespace xt
         chunk_storage_type m_chunks;
     };
 
-    template<class E>
+    template <class E>
     constexpr bool is_chunked(const xexpression<E>& e);
 
-    template<class E>
+    template <class E>
     constexpr bool is_chunked();
 
     /**
      * Creates an in-memory chunked array.
-     * This function returns an uninitialized ``xchunked_array<xarray<T>>``.
+     *
+     * This function returns an uninitialized ``xt::xchunked_array<xt::xarray<T>>``.
+     *
+     * @ingroup xt_xchunked_array
      *
      * @tparam T The type of the elements (e.g. double)
      * @tparam L The layout_type of the array
@@ -198,17 +222,26 @@ namespace xt
      * @param chunk_shape The shape of a chunk
      * @param chunk_memory_layout The layout of each chunk (default: XTENSOR_DEFAULT_LAYOUT)
      *
-     * @return returns a ``xchunked_array<xarray<T>>`` with the given shape, chunk shape and memory layout.
+     * @return returns a ``xt::xchunked_array<xt::xarray<T>>`` with the given shape, chunk shape and memory
+     * layout.
      */
     template <class T, layout_type L = XTENSOR_DEFAULT_LAYOUT, class S>
-    xchunked_array<xarray<xarray<T>>> chunked_array(S&& shape, S&& chunk_shape, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+    xchunked_array<xarray<xarray<T>>>
+    chunked_array(S&& shape, S&& chunk_shape, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
 
     template <class T, layout_type L = XTENSOR_DEFAULT_LAYOUT, class S>
-    xchunked_array<xarray<xarray<T>>> chunked_array(std::initializer_list<S> shape, std::initializer_list<S> chunk_shape, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+    xchunked_array<xarray<xarray<T>>> chunked_array(
+        std::initializer_list<S> shape,
+        std::initializer_list<S> chunk_shape,
+        layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT
+    );
 
     /**
      * Creates an in-memory chunked array.
-     * This function returns a ``xchunked_array<xarray<T>>`` initialized from an expression.
+     *
+     * This function returns a ``xt::xchunked_array<xt::xarray<T>>`` initialized from an expression.
+     *
+     * @ingroup xt_xchunked_array
      *
      * @tparam L The layout_type of the array
      *
@@ -216,7 +249,8 @@ namespace xt
      * @param chunk_shape The shape of a chunk
      * @param chunk_memory_layout The layout of each chunk (default: XTENSOR_DEFAULT_LAYOUT)
      *
-     * @return returns a ``xchunked_array<xarray<T>>`` from the given expression, with the given chunk shape and memory layout.
+     * @return returns a ``xt::xchunked_array<xt::xarray<T>>`` from the given expression, with the given chunk
+     * shape and memory layout.
      */
     template <layout_type L = XTENSOR_DEFAULT_LAYOUT, class E, class S>
     xchunked_array<xarray<xarray<typename E::value_type>>>
@@ -224,18 +258,22 @@ namespace xt
 
     /**
      * Creates an in-memory chunked array.
-     * This function returns a ``xchunked_array<xarray<T>>`` initialized from an expression.
+     *
+     * This function returns a ``xt::xchunked_array<xt::xarray<T>>`` initialized from an expression.
+     *
+     * @ingroup xt_xchunked_array
      *
      * @tparam L The layout_type of the array
      *
      * @param e The expression to initialize the chunked array from
      * @param chunk_memory_layout The layout of each chunk (default: XTENSOR_DEFAULT_LAYOUT)
      *
-     * @return returns a ``xchunked_array<xarray<T>>`` from the given expression, with the expression's chunk shape and the given memory layout.
+     * @return returns a ``xt::xchunked_array<xt::xarray<T>>`` from the given expression, with the
+     * expression's chunk shape and the given memory layout.
      */
     template <layout_type L = XTENSOR_DEFAULT_LAYOUT, class E>
     xchunked_array<xarray<xarray<typename E::value_type>>>
-    chunked_array(const xexpression<E>&e, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+    chunked_array(const xexpression<E>& e, layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
 
     /*******************************
      * chunk_helper implementation *
@@ -251,16 +289,18 @@ namespace xt
         struct chunk_helper_impl
         {
             using is_chunked = std::false_type;
+
             static const auto& chunk_shape(const xexpression<E>& e)
             {
                 return e.derived_cast().shape();
             }
 
             template <class S1, class S2>
-            static void resize(E& chunks, const S1& container_shape, const S2& chunk_shape, layout_type chunk_memory_layout)
+            static void
+            resize(E& chunks, const S1& container_shape, const S2& chunk_shape, layout_type chunk_memory_layout)
             {
                 chunks.resize(container_shape);
-                for(auto& c: chunks)
+                for (auto& c : chunks)
                 {
                     c.resize(chunk_shape, chunk_memory_layout);
                 }
@@ -271,13 +311,15 @@ namespace xt
         struct chunk_helper_impl<E, OP, void_t<OP<E>>>
         {
             using is_chunked = std::true_type;
+
             static const auto& chunk_shape(const xexpression<E>& e)
             {
                 return e.derived_cast().chunk_shape();
             }
 
             template <class S1, class S2>
-            static void resize(E& chunks, const S1& container_shape, const S2& /*chunk_shape*/, layout_type /*chunk_memory_layout*/)
+            static void
+            resize(E& chunks, const S1& container_shape, const S2& /*chunk_shape*/, layout_type /*chunk_memory_layout*/)
             {
                 chunks.resize(container_shape);
             }
@@ -287,13 +329,13 @@ namespace xt
         using chunk_helper = chunk_helper_impl<E, try_chunk_shape>;
     }
 
-    template<class E>
+    template <class E>
     constexpr bool is_chunked(const xexpression<E>&)
     {
         return is_chunked<E>();
     }
 
-    template<class E>
+    template <class E>
     constexpr bool is_chunked()
     {
         using return_type = typename detail::chunk_helper<E>::is_chunked;
@@ -301,14 +343,21 @@ namespace xt
     }
 
     template <class T, layout_type L, class S>
-    inline xchunked_array<xarray<xarray<T>>> chunked_array(S&& shape, S&& chunk_shape, layout_type chunk_memory_layout)
+    inline xchunked_array<xarray<xarray<T>>>
+    chunked_array(S&& shape, S&& chunk_shape, layout_type chunk_memory_layout)
     {
         using chunk_storage = xarray<xarray<T, L>>;
-        return xchunked_array<chunk_storage>(chunk_storage(), std::forward<S>(shape), std::forward<S>(chunk_shape), chunk_memory_layout);
+        return xchunked_array<chunk_storage>(
+            chunk_storage(),
+            std::forward<S>(shape),
+            std::forward<S>(chunk_shape),
+            chunk_memory_layout
+        );
     }
 
     template <class T, layout_type L, class S>
-    xchunked_array<xarray<xarray<T>>> chunked_array(std::initializer_list<S> shape, std::initializer_list<S> chunk_shape, layout_type chunk_memory_layout)
+    xchunked_array<xarray<xarray<T>>>
+    chunked_array(std::initializer_list<S> shape, std::initializer_list<S> chunk_shape, layout_type chunk_memory_layout)
     {
         using sh_type = std::vector<std::size_t>;
         auto sh = xtl::forward_sequence<sh_type, std::initializer_list<S>>(shape);
@@ -353,7 +402,12 @@ namespace xt
 
     template <class CS>
     template <class E, class S>
-    inline xchunked_array<CS>::xchunked_array(const xexpression<E>& e, CS&& chunks, S&& chunk_shape, layout_type chunk_memory_layout)
+    inline xchunked_array<CS>::xchunked_array(
+        const xexpression<E>& e,
+        CS&& chunks,
+        S&& chunk_shape,
+        layout_type chunk_memory_layout
+    )
         : m_chunks(std::move(chunks))
     {
         resize(e.derived_cast().shape(), std::forward<S>(chunk_shape), chunk_memory_layout);
@@ -541,7 +595,6 @@ namespace xt
     inline auto xchunked_array<CS>::chunk_cend() const -> const_chunk_iterator
     {
         return chunk_end();
-
     }
 
     template <class CS>
@@ -550,16 +603,18 @@ namespace xt
     {
         // compute chunk number in each dimension (shape_of_chunks)
         std::vector<std::size_t> shape_of_chunks(shape.size());
-        std::transform
-        (
-            shape.cbegin(), shape.cend(),
+        std::transform(
+            shape.cbegin(),
+            shape.cend(),
             chunk_shape.cbegin(),
             shape_of_chunks.begin(),
             [](auto s, auto cs)
             {
                 std::size_t cn = s / cs;
                 if (s % cs > 0)
-                    cn += std::size_t(1); // edge_chunk
+                {
+                    cn += std::size_t(1);  // edge_chunk
+                }
                 return cn;
             }
         );
@@ -580,7 +635,8 @@ namespace xt
 
     template <class CS>
     template <class Idx>
-    inline std::pair<std::size_t, std::size_t> xchunked_array<CS>::get_chunk_indexes_in_dimension(std::size_t dim, Idx idx) const
+    inline std::pair<std::size_t, std::size_t>
+    xchunked_array<CS>::get_chunk_indexes_in_dimension(std::size_t dim, Idx idx) const
     {
         std::size_t index_of_chunk = static_cast<size_t>(idx) / m_chunk_shape[dim];
         std::size_t index_in_chunk = static_cast<size_t>(idx) - index_of_chunk * m_chunk_shape[dim];
@@ -598,7 +654,7 @@ namespace xt
 
     template <class CS>
     template <class T, std::size_t N>
-    inline auto xchunked_array<CS>::unpack(const std::array<T, N> &arr) const -> static_indexes_type<N>
+    inline auto xchunked_array<CS>::unpack(const std::array<T, N>& arr) const -> static_indexes_type<N>
     {
         std::array<std::size_t, N> arr0;
         std::array<std::size_t, N> arr1;
