@@ -1,11 +1,11 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_COMPLEX_HPP
 #define XTENSOR_COMPLEX_HPP
@@ -21,6 +21,13 @@
 
 namespace xt
 {
+
+    /**
+     * @defgroup xt_xcomplex
+     *
+     * Defined in ``xtensor/xcomplex.hpp``
+     */
+
     /******************************
      * real and imag declarations *
      ******************************/
@@ -41,14 +48,14 @@ namespace xt
         struct complex_helper
         {
             template <class E>
-            static inline auto real(E&& e) noexcept
+            inline static auto real(E&& e) noexcept
             {
                 using real_type = typename std::decay_t<E>::value_type::value_type;
                 return xoffset_view<xclosure_t<E>, real_type, 0>(std::forward<E>(e));
             }
 
             template <class E>
-            static inline auto imag(E&& e) noexcept
+            inline static auto imag(E&& e) noexcept
             {
                 using real_type = typename std::decay_t<E>::value_type::value_type;
                 return xoffset_view<xclosure_t<E>, real_type, sizeof(real_type)>(std::forward<E>(e));
@@ -59,13 +66,13 @@ namespace xt
         struct complex_helper<false>
         {
             template <class E>
-            static inline decltype(auto) real(E&& e) noexcept
+            inline static decltype(auto) real(E&& e) noexcept
             {
                 return std::forward<E>(e);
             }
 
             template <class E>
-            static inline auto imag(E&& e) noexcept
+            inline static auto imag(E&& e) noexcept
             {
                 return zeros<typename std::decay_t<E>::value_type>(e.shape());
             }
@@ -75,15 +82,19 @@ namespace xt
         struct complex_expression_helper
         {
             template <class E>
-            static inline decltype(auto) real(E&& e) noexcept
+            inline static decltype(auto) real(E&& e) noexcept
             {
-                return detail::complex_helper<xtl::is_complex<typename std::decay_t<E>::value_type>::value>::real(std::forward<E>(e));
+                return detail::complex_helper<xtl::is_complex<typename std::decay_t<E>::value_type>::value>::real(
+                    std::forward<E>(e)
+                );
             }
 
             template <class E>
-            static inline decltype(auto) imag(E&& e) noexcept
+            inline static decltype(auto) imag(E&& e) noexcept
             {
-                return detail::complex_helper<xtl::is_complex<typename std::decay_t<E>::value_type>::value>::imag(std::forward<E>(e));
+                return detail::complex_helper<xtl::is_complex<typename std::decay_t<E>::value_type>::value>::imag(
+                    std::forward<E>(e)
+                );
             }
         };
 
@@ -91,13 +102,13 @@ namespace xt
         struct complex_expression_helper<false>
         {
             template <class E>
-            static inline decltype(auto) real(E&& e) noexcept
+            inline static decltype(auto) real(E&& e) noexcept
             {
                 return xtl::forward_real(std::forward<E>(e));
             }
 
             template <class E>
-            static inline decltype(auto) imag(E&& e) noexcept
+            inline static decltype(auto) imag(E&& e) noexcept
             {
                 return xtl::forward_imag(std::forward<E>(e));
             }
@@ -105,49 +116,53 @@ namespace xt
     }
 
     /**
-     * @brief Returns an \ref xexpression representing the real part of the given expression.
+     * Return an xt::xexpression representing the real part of the given expression.
      *
-     * @tparam e the \ref xexpression
+     * The returned expression either hold a const reference to @p e or a copy
+     * depending on whether @p e is an lvalue or an rvalue.
      *
-     * The returned expression either hold a const reference to \p e or a copy
-     * depending on whether \p e is an lvalue or an rvalue.
+     * @ingroup xt_xcomplex
+     * @tparam e The xt::xexpression
      */
     template <class E>
     inline decltype(auto) real(E&& e) noexcept
     {
-        return detail::complex_expression_helper<is_xexpression<std::decay_t<E>>::value>::real(std::forward<E>(e));
+        return detail::complex_expression_helper<is_xexpression<std::decay_t<E>>::value>::real(std::forward<E>(e
+        ));
     }
 
     /**
-     * @brief Returns an \ref xexpression representing the imaginary part of the given expression.
+     * Return an xt::xexpression representing the imaginary part of the given expression.
      *
-     * @tparam e the \ref xexpression
+     * The returned expression either hold a const reference to @p e or a copy
+     * depending on whether @p e is an lvalue or an rvalue.
      *
-     * The returned expression either hold a const reference to \p e or a copy
-     * depending on whether \p e is an lvalue or an rvalue.
+     * @ingroup xt_xcomplex
+     * @tparam e The xt::xexpression
      */
     template <class E>
     inline decltype(auto) imag(E&& e) noexcept
     {
-        return detail::complex_expression_helper<is_xexpression<std::decay_t<E>>::value>::imag(std::forward<E>(e));
+        return detail::complex_expression_helper<is_xexpression<std::decay_t<E>>::value>::imag(std::forward<E>(e
+        ));
     }
 
-#define UNARY_COMPLEX_FUNCTOR(NS, NAME)                             \
-    struct NAME##_fun                                               \
-    {                                                               \
-        template <class T>                                          \
-        constexpr auto operator()(const T& t) const                 \
-        {                                                           \
-            using NS::NAME;                                         \
-            return NAME(t);                                         \
-        }                                                           \
-                                                                    \
-        template <class B>                                          \
-        constexpr auto simd_apply(const B& t) const                 \
-        {                                                           \
-            using NS::NAME;                                         \
-            return NAME(t);                                         \
-        }                                                           \
+#define UNARY_COMPLEX_FUNCTOR(NS, NAME)             \
+    struct NAME##_fun                               \
+    {                                               \
+        template <class T>                          \
+        constexpr auto operator()(const T& t) const \
+        {                                           \
+            using NS::NAME;                         \
+            return NAME(t);                         \
+        }                                           \
+                                                    \
+        template <class B>                          \
+        constexpr auto simd_apply(const B& t) const \
+        {                                           \
+            using NS::NAME;                         \
+            return NAME(t);                         \
+        }                                           \
     }
 
     namespace math
@@ -161,14 +176,14 @@ namespace xt
             }
 
             template <class T>
-            constexpr std::complex<T> conj_impl(const T & real)
+            constexpr std::complex<T> conj_impl(const T& real)
             {
                 return std::complex<T>(real, 0);
             }
-            
+
 #ifdef XTENSOR_USE_XSIMD
             template <class T, class A>
-            xsimd::complex_batch_type_t< xsimd::batch<T, A>> conj_impl(const xsimd::batch<T, A>& z)
+            xsimd::complex_batch_type_t<xsimd::batch<T, A>> conj_impl(const xsimd::batch<T, A>& z)
             {
                 return xsimd::conj(z);
             }
@@ -183,9 +198,10 @@ namespace xt
 #undef UNARY_COMPLEX_FUNCTOR
 
     /**
-     * @brief Returns an \ref xfunction evaluating to the complex conjugate of the given expression.
+     * Return an xt::xfunction evaluating to the complex conjugate of the given expression.
      *
-     * @param e the \ref xexpression
+     * @ingroup xt_xcomplex
+     * @param e the xt::xexpression
      */
     template <class E>
     inline auto conj(E&& e) noexcept
@@ -196,8 +212,10 @@ namespace xt
     }
 
     /**
-     * @brief Calculates the phase angle (in radians) elementwise for the complex numbers in e.
-     * @param e the \ref xexpression
+     * Calculates the phase angle (in radians) elementwise for the complex numbers in @p e.
+     *
+     * @ingroup xt_xcomplex
+     * @param e the xt::xexpression
      */
     template <class E>
     inline auto arg(E&& e) noexcept
@@ -208,9 +226,12 @@ namespace xt
     }
 
     /**
-     * @brief Calculates the phase angle elementwise for the complex numbers in e.
-     * Note that this function might be slightly less perfomant than \ref arg.
-     * @param e the \ref xexpression
+     * Calculates the phase angle elementwise for the complex numbers in @p e.
+     *
+     * Note that this function might be slightly less performant than xt::arg.
+     *
+     * @ingroup xt_xcomplex
+     * @param e the xt::xexpression
      * @param deg calculate angle in degrees instead of radians
      */
     template <class E>
@@ -226,9 +247,11 @@ namespace xt
     }
 
     /**
-     * Calculates the squared magnitude elementwise for the complex numbers in e.
-     * Equivalent to pow(real(e), 2) + pow(imag(e), 2).
-     * @param e the \ref xexpression
+     * Calculates the squared magnitude elementwise for the complex numbers in @p e.
+     *
+     * Equivalent to ``xt::pow(xt::real(e), 2) + xt::pow(xt::imag(e), 2)``.
+     * @ingroup xt_xcomplex
+     * @param e the xt::xexpression
      */
     template <class E>
     inline auto norm(E&& e) noexcept
