@@ -1,22 +1,29 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_EVAL_HPP
 #define XTENSOR_EVAL_HPP
 
 #include "xexpression_traits.hpp"
-#include "xtensor_forward.hpp"
 #include "xshape.hpp"
+#include "xtensor_forward.hpp"
 
 namespace xt
 {
 
+    /**
+     * @defgroup xt_xeval
+     *
+     * Evaluation functions.
+     * Defined in ``xtensor/xeval.hpp``
+     */
+
     namespace detail
     {
         template <class T>
@@ -25,17 +32,18 @@ namespace xt
 
     /**
      * Force evaluation of xexpression.
-     * @return xarray or xtensor depending on shape type
      *
-     * \code{.cpp}
-     * xarray<double> a = {1,2,3,4};
+     * @code{.cpp}
+     * xt::xarray<double> a = {1, 2, 3, 4};
      * auto&& b = xt::eval(a); // b is a reference to a, no copy!
      * auto&& c = xt::eval(a + b); // c is xarray<double>, not an xexpression
-     * \endcode
+     * @endcode
+     *
+     * @ingroup xt_xeval
+     * @return xt::xarray or xt::xtensor depending on shape type
      */
     template <class T>
-    inline auto eval(T&& t)
-        -> std::enable_if_t<detail::is_container<std::decay_t<T>>::value, T&&>
+    inline auto eval(T&& t) -> std::enable_if_t<detail::is_container<std::decay_t<T>>::value, T&&>
     {
         return std::forward<T>(t);
     }
@@ -47,6 +55,7 @@ namespace xt
     {
         return std::forward<T>(t);
     }
+
     /// @endcond
 
     namespace detail
@@ -101,59 +110,67 @@ namespace xt
          *****************************************/
 
         template <class E, layout_type L>
-        using as_xtensor_container_t = xtensor<typename std::decay_t<E>::value_type,
-                                               std::tuple_size<typename std::decay_t<E>::shape_type>::value,
-                                               layout_remove_any(L)>;
+        using as_xtensor_container_t = xtensor<
+            typename std::decay_t<E>::value_type,
+            std::tuple_size<typename std::decay_t<E>::shape_type>::value,
+            layout_remove_any(L)>;
     }
 
     /**
      * Force evaluation of xexpression not providing a data interface
      * and convert to the required layout.
-     * 
-     * @warning This function should be used in a local context only.
-     * Returning the value returned by this function could lead to a dangling reference.
-     * 
-     * @return The expression when it already provides a data interface with the correct layout,
-     * an evaluated xarray or xtensor depending on shape type otherwise.
      *
-     * \code{.cpp}
-     * xarray<double, layout_type::row_major> a = {1,2,3,4};
-     * auto&& b = xt::as_strided(a); // b is a reference to a, no copy!
-     * auto&& c = xt::as_strided<layout_type::column_major>(a); // b is xarray<double> with the required layout
-     * auto&& a_cast = xt::cast<int>(a); // a_cast is an xexpression
-     * auto&& d = xt::as_strided(a_cast); // d is xarray<int>, not an xexpression
-     * auto&& e = xt::as_strided<layout_type::column_major>(a_cast); // d is xarray<int> with the required layout
-     * \endcode
+     * @code{.cpp}
+     * xt::xarray<double, xt::layout_type::row_major> a = {1, 2, 3, 4};
+     *
+     * // take reference to a (no copy!)
+     * auto&& b = xt::as_strided(a);
+     *
+     * // xarray<double> with the required layout
+     * auto&& c = xt::as_strided<xt::layout_type::column_major>(a);
+     *
+     * // xexpression
+     * auto&& a_cast = xt::cast<int>(a);
+     *
+     * // xarray<int>, not an xexpression
+     * auto&& d = xt::as_strided(a_cast);
+     *
+     * // xarray<int> with the required layout
+     * auto&& e = xt::as_strided<xt::layout_type::column_major>(a_cast);
+     * @endcode
+     *
+     * @warning This function should be used in a local context only.
+     *          Returning the value returned by this function could lead to a dangling reference.
+     * @ingroup xt_xeval
+     * @return The expression when it already provides a data interface with the correct layout,
+     *         an evaluated xt::xarray or xt::xtensor depending on shape type otherwise.
      */
     template <layout_type L = layout_type::any, class E>
     inline auto as_strided(E&& e)
-        -> std::enable_if_t<has_data_interface<std::decay_t<E>>::value
-                            && detail::has_same_layout<L, E>(),
-                            E&&>
+        -> std::enable_if_t<has_data_interface<std::decay_t<E>>::value && detail::has_same_layout<L, E>(), E&&>
     {
         return std::forward<E>(e);
     }
 
     /// @cond DOXYGEN_INCLUDE_SFINAE
     template <layout_type L = layout_type::any, class E>
-    inline auto as_strided(E&& e)
-        -> std::enable_if_t<(!(has_data_interface<std::decay_t<E>>::value
-                               && detail::has_same_layout<L, E>()))
-                            && detail::has_fixed_dims<E>(),
-                            detail::as_xtensor_container_t<E, L>>
+    inline auto as_strided(E&& e) -> std::enable_if_t<
+        (!(has_data_interface<std::decay_t<E>>::value && detail::has_same_layout<L, E>()))
+            && detail::has_fixed_dims<E>(),
+        detail::as_xtensor_container_t<E, L>>
     {
         return e;
     }
 
     template <layout_type L = layout_type::any, class E>
-    inline auto as_strided(E&& e)
-        -> std::enable_if_t<(!(has_data_interface<std::decay_t<E>>::value
-                               && detail::has_same_layout<L, E>()))
-                            && (!detail::has_fixed_dims<E>()),
-                            detail::as_xarray_container_t<E, L>>
+    inline auto as_strided(E&& e) -> std::enable_if_t<
+        (!(has_data_interface<std::decay_t<E>>::value && detail::has_same_layout<L, E>()))
+            && (!detail::has_fixed_dims<E>()),
+        detail::as_xarray_container_t<E, L>>
     {
         return e;
     }
+
     /// @endcond
 }
 
