@@ -1,11 +1,11 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_FIXED_HPP
 #define XTENSOR_FIXED_HPP
@@ -19,9 +19,9 @@
 #include <xtl/xsequence.hpp>
 
 #include "xcontainer.hpp"
-#include "xstrides.hpp"
-#include "xstorage.hpp"
 #include "xsemantic.hpp"
+#include "xstorage.hpp"
+#include "xstrides.hpp"
 #include "xtensor_config.hpp"
 
 namespace xtl
@@ -99,31 +99,33 @@ namespace xt
         template <std::size_t I, std::size_t Y, std::size_t... X>
         struct calculate_stride<layout_type::column_major, I, Y, X...>
         {
-            constexpr static std::ptrdiff_t value = Y * calculate_stride<layout_type::column_major, I - 1, X...>::value;
+            static constexpr std::ptrdiff_t value = Y
+                                                    * calculate_stride<layout_type::column_major, I - 1, X...>::value;
         };
 
         template <std::size_t Y, std::size_t... X>
         struct calculate_stride<layout_type::column_major, 0, Y, X...>
         {
-            constexpr static std::ptrdiff_t value = 1;
+            static constexpr std::ptrdiff_t value = 1;
         };
 
         template <std::size_t I, std::size_t... X>
         struct calculate_stride_row_major
         {
-            constexpr static std::ptrdiff_t value = at<sizeof...(X) - I, X...>::value * calculate_stride_row_major<I - 1, X...>::value;
+            static constexpr std::ptrdiff_t value = at<sizeof...(X) - I, X...>::value
+                                                    * calculate_stride_row_major<I - 1, X...>::value;
         };
 
         template <std::size_t... X>
         struct calculate_stride_row_major<0, X...>
         {
-            constexpr static std::ptrdiff_t value = 1;
+            static constexpr std::ptrdiff_t value = 1;
         };
 
         template <std::size_t I, std::size_t... X>
         struct calculate_stride<layout_type::row_major, I, X...>
         {
-            constexpr static std::ptrdiff_t value = calculate_stride_row_major<sizeof...(X) - I - 1, X...>::value;
+            static constexpr std::ptrdiff_t value = calculate_stride_row_major<sizeof...(X) - I - 1, X...>::value;
         };
 
         namespace workaround
@@ -134,10 +136,10 @@ namespace xt
             template <layout_type L, size_t I, size_t... X>
             struct computed_strides<L, I, std::index_sequence<X...>>
             {
-                constexpr static std::ptrdiff_t value = calculate_stride<L, I, X...>::value;
+                static constexpr std::ptrdiff_t value = calculate_stride<L, I, X...>::value;
             };
 
-            template <layout_type L, size_t I, class SEQ >
+            template <layout_type L, size_t I, class SEQ>
             constexpr std::ptrdiff_t get_computed_strides(bool cond)
             {
                 return cond ? 0 : computed_strides<L, I, SEQ>::value;
@@ -147,13 +149,15 @@ namespace xt
         template <layout_type L, class R, std::size_t... X, std::size_t... I>
         constexpr R get_strides_impl(const xt::fixed_shape<X...>& shape, std::index_sequence<I...>)
         {
-            static_assert((L == layout_type::row_major) || (L == layout_type::column_major),
-                          "Layout not supported for fixed array");
+            static_assert(
+                (L == layout_type::row_major) || (L == layout_type::column_major),
+                "Layout not supported for fixed array"
+            );
 #if (_MSC_VER >= 1910)
             using temp_type = std::index_sequence<X...>;
-            return R({ workaround::get_computed_strides<L, I, temp_type>(shape[I] == 1)... });
+            return R({workaround::get_computed_strides<L, I, temp_type>(shape[I] == 1)...});
 #else
-            return R({ shape[I] == 1 ? 0 : calculate_stride<L, I, X...>::value... });
+            return R({shape[I] == 1 ? 0 : calculate_stride<L, I, X...>::value...});
 #endif
         }
 
@@ -169,20 +173,20 @@ namespace xt
         template <std::size_t Y, std::size_t... X>
         struct fixed_compute_size_impl<Y, X...>
         {
-            constexpr static std::size_t value = Y * fixed_compute_size_impl<X...>::value;
+            static constexpr std::size_t value = Y * fixed_compute_size_impl<X...>::value;
         };
 
         template <std::size_t X>
         struct fixed_compute_size_impl<X>
         {
-            constexpr static std::size_t value = X;
+            static constexpr std::size_t value = X;
         };
 
         template <>
         struct fixed_compute_size_impl<>
         {
             // support for 0D xtensor fixed (empty shape = xshape<>)
-            constexpr static std::size_t value = 1;
+            static constexpr std::size_t value = 1;
         };
 
         // TODO unify with constexpr compute_size when dropping MSVC 2015
@@ -192,7 +196,7 @@ namespace xt
         template <std::size_t... X>
         struct fixed_compute_size<xt::fixed_shape<X...>>
         {
-            constexpr static std::size_t value = fixed_compute_size_impl<X...>::value;
+            static constexpr std::size_t value = fixed_compute_size_impl<X...>::value;
         };
 
         template <class V, std::size_t... X>
@@ -227,8 +231,7 @@ namespace xt
     template <class S, class T>
     constexpr T get_backstrides(const S& shape, const T& strides) noexcept
     {
-        return detail::get_backstrides_impl(shape, strides,
-                                            std::make_index_sequence<std::tuple_size<T>::value>{});
+        return detail::get_backstrides_impl(shape, strides, std::make_index_sequence<std::tuple_size<T>::value>{});
     }
 
     template <class V, class S>
@@ -254,12 +257,12 @@ namespace xt
         using inner_backstrides_type = backstrides_type;
 
         // NOTE: 0D (S::size() == 0) results in storage for 1 element (scalar)
-    #if defined(_MSC_VER) && _MSC_VER < 1910 && !defined(_WIN64)
+#if defined(_MSC_VER) && _MSC_VER < 1910 && !defined(_WIN64)
         // WORKAROUND FOR MSVC 2015 32 bit, fallback to unaligned container for 0D scalar case
         using storage_type = std::array<ET, detail::fixed_compute_size<S>::value>;
-    #else
+#else
         using storage_type = aligned_array<ET, detail::fixed_compute_size<S>::value>;
-    #endif
+#endif
 
         using reference = typename storage_type::reference;
         using const_reference = typename storage_type::const_reference;
@@ -314,8 +317,8 @@ namespace xt
         using temporary_type = typename semantic_base::temporary_type;
         using expression_tag = Tag;
 
-        constexpr static std::size_t N = std::tuple_size<shape_type>::value;
-        constexpr static std::size_t rank = N;
+        static constexpr std::size_t N = std::tuple_size<shape_type>::value;
+        static constexpr std::size_t rank = N;
 
         xfixed_container() = default;
         xfixed_container(const value_type& v);
@@ -351,7 +354,7 @@ namespace xt
         void resize(ST&& shape, const strides_type& strides) const;
 
         template <class ST = std::array<std::size_t, N>>
-        auto const& reshape(ST&& shape, layout_type layout = L) const;
+        const auto& reshape(ST&& shape, layout_type layout = L) const;
 
         template <class ST>
         bool broadcast_shape(ST& s, bool reuse_cache = false) const;
@@ -365,7 +368,8 @@ namespace xt
 
         XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_shape_type m_shape = S();
         XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_strides_type m_strides = get_strides<L, inner_strides_type>(S());
-        XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_backstrides_type m_backstrides = get_backstrides(m_shape, m_strides);
+        XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_backstrides_type
+            m_backstrides = get_backstrides(m_shape, m_strides);
 
         storage_type& storage_impl() noexcept;
         const storage_type& storage_impl() const noexcept;
@@ -380,13 +384,16 @@ namespace xt
 #ifdef XTENSOR_HAS_CONSTEXPR_ENHANCED
     // Out of line definitions to prevent linker errors prior to C++17
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_container<ET, S, L, SH, Tag>::inner_shape_type xfixed_container<ET, S, L, SH, Tag>::m_shape;
+    constexpr
+        typename xfixed_container<ET, S, L, SH, Tag>::inner_shape_type xfixed_container<ET, S, L, SH, Tag>::m_shape;
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_container<ET, S, L, SH, Tag>::inner_strides_type xfixed_container<ET, S, L, SH, Tag>::m_strides;
+    constexpr
+        typename xfixed_container<ET, S, L, SH, Tag>::inner_strides_type xfixed_container<ET, S, L, SH, Tag>::m_strides;
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_container<ET, S, L, SH, Tag>::inner_backstrides_type xfixed_container<ET, S, L, SH, Tag>::m_backstrides;
+    constexpr typename xfixed_container<ET, S, L, SH, Tag>::inner_backstrides_type
+        xfixed_container<ET, S, L, SH, Tag>::m_backstrides;
 #endif
 
     /****************************************
@@ -456,7 +463,7 @@ namespace xt
         using temporary_type = typename semantic_base::temporary_type;
         using expression_tag = Tag;
 
-        constexpr static std::size_t N = S::size();
+        static constexpr std::size_t N = S::size();
 
         xfixed_adaptor(storage_type&& data);
         xfixed_adaptor(const storage_type& data);
@@ -498,7 +505,8 @@ namespace xt
 
         XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_shape_type m_shape = S();
         XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_strides_type m_strides = get_strides<L, inner_strides_type>(S());
-        XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_backstrides_type m_backstrides = get_backstrides(m_shape, m_strides);
+        XTENSOR_CONSTEXPR_ENHANCED_STATIC inner_backstrides_type
+            m_backstrides = get_backstrides(m_shape, m_strides);
 
         storage_type& storage_impl() noexcept;
         const storage_type& storage_impl() const noexcept;
@@ -513,13 +521,16 @@ namespace xt
 #ifdef XTENSOR_HAS_CONSTEXPR_ENHANCED
     // Out of line definitions to prevent linker errors prior to C++17
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_shape_type xfixed_adaptor<EC, S, L, SH, Tag>::m_shape;
+    constexpr
+        typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_shape_type xfixed_adaptor<EC, S, L, SH, Tag>::m_shape;
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_strides_type xfixed_adaptor<EC, S, L, SH, Tag>::m_strides;
+    constexpr
+        typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_strides_type xfixed_adaptor<EC, S, L, SH, Tag>::m_strides;
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    constexpr typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_backstrides_type xfixed_adaptor<EC, S, L, SH, Tag>::m_backstrides;
+    constexpr typename xfixed_adaptor<EC, S, L, SH, Tag>::inner_backstrides_type
+        xfixed_adaptor<EC, S, L, SH, Tag>::m_backstrides;
 #endif
 
     /************************************
@@ -533,7 +544,7 @@ namespace xt
 
     /**
      * Create an uninitialized xfixed_container.
-     * Note this function is only provided for homogenity, and the shape & layout argument is
+     * Note this function is only provided for homogeneity, and the shape & layout argument is
      * disregarded (the template shape is always used).
      *
      * @param shape the shape of the xfixed_container (unused!)
@@ -542,8 +553,8 @@ namespace xt
     template <class ET, class S, layout_type L, bool SH, class Tag>
     inline xfixed_container<ET, S, L, SH, Tag>::xfixed_container(const inner_shape_type& shape, layout_type l)
     {
-        (void)(shape);
-        (void)(l);
+        (void) (shape);
+        (void) (l);
         XTENSOR_ASSERT(shape.size() == N && std::equal(shape.begin(), shape.end(), m_shape.begin()));
         XTENSOR_ASSERT(L == l);
     }
@@ -553,15 +564,14 @@ namespace xt
     {
         if (this->size() != 1)
         {
-            XTENSOR_THROW(std::runtime_error,
-                          "wrong shape for scalar assignment (has to be xshape<>).");
+            XTENSOR_THROW(std::runtime_error, "wrong shape for scalar assignment (has to be xshape<>).");
         }
         m_storage[0] = v;
     }
 
     /**
      * Create an xfixed_container, and initialize with the value of v.
-     * Note, the shape argument to this function is only provided for homogenity,
+     * Note, the shape argument to this function is only provided for homogeneity,
      * and the shape argument is disregarded (the template shape is always used).
      *
      * @param shape the shape of the xfixed_container (unused!)
@@ -569,10 +579,14 @@ namespace xt
      * @param l the layout_type of the xfixed_container (unused!)
      */
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    inline xfixed_container<ET, S, L, SH, Tag>::xfixed_container(const inner_shape_type& shape, value_type v, layout_type l)
+    inline xfixed_container<ET, S, L, SH, Tag>::xfixed_container(
+        const inner_shape_type& shape,
+        value_type v,
+        layout_type l
+    )
     {
-        (void)(shape);
-        (void)(l);
+        (void) (shape);
+        (void) (l);
         XTENSOR_ASSERT(shape.size() == N && std::equal(shape.begin(), shape.end(), m_shape.begin()));
         XTENSOR_ASSERT(L == l);
         std::fill(m_storage.begin(), m_storage.end(), v);
@@ -619,19 +633,23 @@ namespace xt
 
     /**
      * Allocates an xfixed_container with shape S with values from a C array.
-     * The type returned by get_init_type_t is raw C array ``value_type[X][Y][Z]`` for ``xt::xshape<X, Y, Z>``.
-     * C arrays can be initialized with the initializer list syntax, but the size is checked at compile
-     * time to prevent errors.
+     * The type returned by get_init_type_t is raw C array ``value_type[X][Y][Z]`` for
+     * ``xt::xshape<X, Y, Z>``. C arrays can be initialized with the initializer list syntax,
+     * but the size is checked at compile time to prevent errors.
      * Note: for clang < 3.8 this is an initializer_list and the size is not checked at compile-or runtime.
      */
     template <class ET, class S, layout_type L, bool SH, class Tag>
     template <class IX, class EN>
     inline xfixed_container<ET, S, L, SH, Tag>::xfixed_container(nested_initializer_list_t<value_type, N> t)
     {
-        XTENSOR_ASSERT_MSG(detail::check_initializer_list_shape<N>::run(t, this->shape()) == true, "initializer list shape does not match fixed shape");
-	constexpr auto tmp = layout_type::row_major;
-	L == tmp ? nested_copy(m_storage.begin(), t) : nested_copy(this->template begin<tmp>(), t);
+        XTENSOR_ASSERT_MSG(
+            detail::check_initializer_list_shape<N>::run(t, this->shape()) == true,
+            "initializer list shape does not match fixed shape"
+        );
+        constexpr auto tmp = layout_type::row_major;
+        L == tmp ? nested_copy(m_storage.begin(), t) : nested_copy(this->template begin<tmp>(), t);
     }
+
     //@}
 
     /**
@@ -657,6 +675,7 @@ namespace xt
     {
         return semantic_base::operator=(e);
     }
+
     //@}
 
     /**
@@ -667,7 +686,7 @@ namespace xt
     template <class ST>
     inline void xfixed_container<ET, S, L, SH, Tag>::resize(ST&& shape, bool) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
         XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size());
     }
 
@@ -679,9 +698,11 @@ namespace xt
     template <class ST>
     inline void xfixed_container<ET, S, L, SH, Tag>::resize(ST&& shape, layout_type l) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
-        (void)(l);
-        XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && L == l);
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (l);
+        XTENSOR_ASSERT(
+            std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && L == l
+        );
     }
 
     /**
@@ -692,10 +713,12 @@ namespace xt
     template <class ST>
     inline void xfixed_container<ET, S, L, SH, Tag>::resize(ST&& shape, const strides_type& strides) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
-        (void)(strides);
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (strides);
         XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size());
-        XTENSOR_ASSERT(std::equal(strides.begin(), strides.end(), m_strides.begin()) && strides.size() == m_strides.size());
+        XTENSOR_ASSERT(
+            std::equal(strides.begin(), strides.end(), m_strides.begin()) && strides.size() == m_strides.size()
+        );
     }
 
     /**
@@ -703,9 +726,10 @@ namespace xt
      */
     template <class ET, class S, layout_type L, bool SH, class Tag>
     template <class ST>
-    inline auto const& xfixed_container<ET, S, L, SH, Tag>::reshape(ST&& shape, layout_type layout) const
+    inline const auto& xfixed_container<ET, S, L, SH, Tag>::reshape(ST&& shape, layout_type layout) const
     {
-        if (!(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && layout == L))
+        if (!(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size()
+              && layout == L))
         {
             XTENSOR_THROW(std::runtime_error, "Trying to reshape xtensor_fixed with different shape or layout.");
         }
@@ -729,9 +753,8 @@ namespace xt
     inline bool xfixed_container<ET, S, L, SH, Tag>::is_contiguous() const noexcept
     {
         using str_type = typename inner_strides_type::value_type;
-        return m_strides.empty()
-            || (layout() == layout_type::row_major && m_strides.back() == str_type(1))
-            || (layout() == layout_type::column_major && m_strides.front() == str_type(1));
+        return m_strides.empty() || (layout() == layout_type::row_major && m_strides.back() == str_type(1))
+               || (layout() == layout_type::column_major && m_strides.front() == str_type(1));
     }
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
@@ -747,19 +770,22 @@ namespace xt
     }
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::shape_impl() const noexcept -> const inner_shape_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::shape_impl() const noexcept
+        -> const inner_shape_type&
     {
         return m_shape;
     }
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::strides_impl() const noexcept -> const inner_strides_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::strides_impl() const noexcept
+        -> const inner_strides_type&
     {
         return m_strides;
     }
 
     template <class ET, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::backstrides_impl() const noexcept -> const inner_backstrides_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_container<ET, S, L, SH, Tag>::backstrides_impl() const noexcept
+        -> const inner_backstrides_type&
     {
         return m_backstrides;
     }
@@ -778,7 +804,8 @@ namespace xt
      */
     template <class EC, class S, layout_type L, bool SH, class Tag>
     inline xfixed_adaptor<EC, S, L, SH, Tag>::xfixed_adaptor(storage_type&& data)
-        : base_type(), m_storage(std::move(data))
+        : base_type()
+        , m_storage(std::move(data))
     {
     }
 
@@ -788,7 +815,8 @@ namespace xt
      */
     template <class EC, class S, layout_type L, bool SH, class Tag>
     inline xfixed_adaptor<EC, S, L, SH, Tag>::xfixed_adaptor(const storage_type& data)
-        : base_type(), m_storage(data)
+        : base_type()
+        , m_storage(data)
     {
     }
 
@@ -800,9 +828,11 @@ namespace xt
     template <class EC, class S, layout_type L, bool SH, class Tag>
     template <class D>
     inline xfixed_adaptor<EC, S, L, SH, Tag>::xfixed_adaptor(D&& data)
-        : base_type(), m_storage(std::forward<D>(data))
+        : base_type()
+        , m_storage(std::forward<D>(data))
     {
     }
+
     //@}
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
@@ -842,6 +872,7 @@ namespace xt
     {
         return semantic_base::operator=(e);
     }
+
     //@}
 
     /**
@@ -852,7 +883,7 @@ namespace xt
     template <class ST>
     inline void xfixed_adaptor<ET, S, L, SH, Tag>::resize(ST&& shape, bool) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
         XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size());
     }
 
@@ -864,9 +895,11 @@ namespace xt
     template <class ST>
     inline void xfixed_adaptor<ET, S, L, SH, Tag>::resize(ST&& shape, layout_type l) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
-        (void)(l);
-        XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && L == l);
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (l);
+        XTENSOR_ASSERT(
+            std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && L == l
+        );
     }
 
     /**
@@ -877,10 +910,12 @@ namespace xt
     template <class ST>
     inline void xfixed_adaptor<ET, S, L, SH, Tag>::resize(ST&& shape, const strides_type& strides) const
     {
-        (void)(shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
-        (void)(strides);
+        (void) (shape);  // remove unused parameter warning if XTENSOR_ASSERT undefined
+        (void) (strides);
         XTENSOR_ASSERT(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size());
-        XTENSOR_ASSERT(std::equal(strides.begin(), strides.end(), m_strides.begin()) && strides.size() == m_strides.size());
+        XTENSOR_ASSERT(
+            std::equal(strides.begin(), strides.end(), m_strides.begin()) && strides.size() == m_strides.size()
+        );
     }
 
     /**
@@ -888,9 +923,10 @@ namespace xt
      */
     template <class ET, class S, layout_type L, bool SH, class Tag>
     template <class ST>
-    inline auto const& xfixed_adaptor<ET, S, L, SH, Tag>::reshape(ST&& shape, layout_type layout) const
+    inline const auto& xfixed_adaptor<ET, S, L, SH, Tag>::reshape(ST&& shape, layout_type layout) const
     {
-        if (!(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size() && layout == L))
+        if (!(std::equal(shape.begin(), shape.end(), m_shape.begin()) && shape.size() == m_shape.size()
+              && layout == L))
         {
             XTENSOR_THROW(std::runtime_error, "Trying to reshape xtensor_fixed with different shape or layout.");
         }
@@ -926,25 +962,27 @@ namespace xt
     inline bool xfixed_adaptor<EC, S, L, SH, Tag>::is_contiguous() const noexcept
     {
         using str_type = typename inner_strides_type::value_type;
-        return m_strides.empty()
-            || (layout() == layout_type::row_major && m_strides.back() == str_type(1))
-            || (layout() == layout_type::column_major && m_strides.front() == str_type(1));
+        return m_strides.empty() || (layout() == layout_type::row_major && m_strides.back() == str_type(1))
+               || (layout() == layout_type::column_major && m_strides.front() == str_type(1));
     }
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::shape_impl() const noexcept -> const inner_shape_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::shape_impl() const noexcept
+        -> const inner_shape_type&
     {
         return m_shape;
     }
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::strides_impl() const noexcept -> const inner_strides_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::strides_impl() const noexcept
+        -> const inner_strides_type&
     {
         return m_strides;
     }
 
     template <class EC, class S, layout_type L, bool SH, class Tag>
-    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::backstrides_impl() const noexcept -> const inner_backstrides_type&
+    XTENSOR_CONSTEXPR_RETURN auto xfixed_adaptor<EC, S, L, SH, Tag>::backstrides_impl() const noexcept
+        -> const inner_backstrides_type&
     {
         return m_backstrides;
     }
