@@ -1,11 +1,11 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_ITERABLE_HPP
 #define XTENSOR_ITERABLE_HPP
@@ -323,11 +323,15 @@ namespace xt
         static constexpr layout_type static_layout = inner_types::layout;
 
 #if defined(_MSC_VER) && _MSC_VER >= 1910
-        // Workaround for compiler bug in Visual Studio 2017 with respect to alias templates with non-type parameters.
+        // Workaround for compiler bug in Visual Studio 2017 with respect to alias templates with non-type
+        // parameters.
         template <layout_type L>
         using layout_iterator = xiterator<typename iterable_base::stepper, typename iterable_base::inner_shape_type*, L>;
         template <layout_type L>
-        using const_layout_iterator = xiterator<typename iterable_base::const_stepper, typename iterable_base::inner_shape_type*, L>;
+        using const_layout_iterator = xiterator<
+            typename iterable_base::const_stepper,
+            typename iterable_base::inner_shape_type*,
+            L>;
         template <layout_type L>
         using reverse_layout_iterator = std::reverse_iterator<layout_iterator<L>>;
         template <layout_type L>
@@ -368,7 +372,10 @@ namespace xt
         template <layout_type L>
         using select_reverse_iterator = select_iterator_impl<L, reverse_linear_iterator, reverse_layout_iterator<L>>;
         template <layout_type L>
-        using select_const_reverse_iterator = select_iterator_impl<L, const_reverse_linear_iterator, const_reverse_layout_iterator<L>>;
+        using select_const_reverse_iterator = select_iterator_impl<
+            L,
+            const_reverse_linear_iterator,
+            const_reverse_layout_iterator<L>>;
 
         using iterator = select_iterator<XTENSOR_DEFAULT_TRAVERSAL>;
         using const_iterator = select_const_iterator<XTENSOR_DEFAULT_TRAVERSAL>;
@@ -493,6 +500,7 @@ namespace xt
     {
         return this->template get_cend<L>(true);
     }
+
     //@}
 
     /**
@@ -544,6 +552,7 @@ namespace xt
     {
         return const_reverse_layout_iterator<L>(get_cbegin<L>(false));
     }
+
     //@}
 
     /**
@@ -605,6 +614,7 @@ namespace xt
     {
         return get_cend<L, S>(shape, true);
     }
+
     //@}
 
     /**
@@ -620,7 +630,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::rbegin(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::rbegin(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return crbegin<L, S>(shape);
     }
@@ -634,7 +645,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::rend(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::rend(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return crend<L, S>(shape);
     }
@@ -648,7 +660,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::crbegin(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::crbegin(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return const_reverse_broadcast_iterator<S, L>(get_cend<L, S>(shape, true));
     }
@@ -662,10 +675,12 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::crend(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::crend(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return const_reverse_broadcast_iterator<S, L>(get_cbegin<L, S>(shape, false));
     }
+
     //@}
 
     template <class D>
@@ -684,14 +699,16 @@ namespace xt
 
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::get_cbegin(const S& shape, bool end_index) const noexcept -> const_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::get_cbegin(const S& shape, bool end_index) const noexcept
+        -> const_broadcast_iterator<S, L>
     {
         return const_broadcast_iterator<S, L>(get_stepper_begin(shape), shape, end_index);
     }
 
     template <class D>
     template <layout_type L, class S>
-    inline auto xconst_iterable<D>::get_cend(const S& shape, bool end_index) const noexcept -> const_broadcast_iterator<S, L>
+    inline auto xconst_iterable<D>::get_cend(const S& shape, bool end_index) const noexcept
+        -> const_broadcast_iterator<S, L>
     {
         return const_broadcast_iterator<S, L>(get_stepper_end(shape, L), shape, end_index);
     }
@@ -705,7 +722,8 @@ namespace xt
 
     template <class D>
     template <class S>
-    inline auto xconst_iterable<D>::get_stepper_end(const S& shape, layout_type l) const noexcept -> const_stepper
+    inline auto xconst_iterable<D>::get_stepper_end(const S& shape, layout_type l) const noexcept
+        -> const_stepper
     {
         return derived_cast().stepper_end(shape, l);
     }
@@ -752,6 +770,7 @@ namespace xt
     {
         return get_end<L>(true);
     }
+
     //@}
 
     /**
@@ -780,6 +799,7 @@ namespace xt
     {
         return reverse_layout_iterator<L>(get_begin<L>(false));
     }
+
     //@}
 
     /**
@@ -813,6 +833,7 @@ namespace xt
     {
         return get_end<L, S>(shape, true);
     }
+
     //@}
 
     /**
@@ -846,6 +867,7 @@ namespace xt
     {
         return reverse_broadcast_iterator<S, L>(get_begin<L, S>(shape, false));
     }
+
     //@}
 
     template <class D>
@@ -914,25 +936,29 @@ namespace xt
      * xcontiguous_iterable implementation *
      ***************************************/
 
-     /**
-      * @name Iterators
-      */
-     //@{
-     /**
-      * Returns an iterator to the first element of the expression.
-      * @tparam L order used for the traversal. Default value is \c XTENSOR_DEFAULT_TRAVERSAL.
-      */
+    /**
+     * @name Iterators
+     */
+    //@{
+    /**
+     * Returns an iterator to the first element of the expression.
+     * @tparam L order used for the traversal. Default value is \c XTENSOR_DEFAULT_TRAVERSAL.
+     */
     template <class D>
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::begin() noexcept -> select_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_begin();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template begin<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_begin();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template begin<L>();
+            }
+        );
     }
 
     /**
@@ -944,13 +970,17 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::end() noexcept -> select_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_end();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template end<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_end();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template end<L>();
+            }
+        );
     }
 
     /**
@@ -984,13 +1014,17 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::cbegin() const noexcept -> select_const_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_cbegin();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template cbegin<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_cbegin();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template cbegin<L>();
+            }
+        );
     }
 
     /**
@@ -1002,14 +1036,19 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::cend() const noexcept -> select_const_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_cend();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template cend<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_cend();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template cend<L>();
+            }
+        );
     }
+
     //@}
 
     /**
@@ -1024,13 +1063,17 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::rbegin() noexcept -> select_reverse_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_rbegin();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template rbegin<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_rbegin();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template rbegin<L>();
+            }
+        );
     }
 
     /**
@@ -1042,13 +1085,17 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::rend() noexcept -> select_reverse_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_rend();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template rend<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_rend();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template rend<L>();
+            }
+        );
     }
 
     /**
@@ -1062,7 +1109,6 @@ namespace xt
         return this->template crbegin<L>();
     }
 
-
     /**
      * Returns a constant iterator to the element following the last element
      * of the reversed expression.
@@ -1083,13 +1129,17 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::crbegin() const noexcept -> select_const_reverse_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_crbegin();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template crbegin<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_crbegin();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template crbegin<L>();
+            }
+        );
     }
 
     /**
@@ -1101,26 +1151,32 @@ namespace xt
     template <layout_type L>
     inline auto xcontiguous_iterable<D>::crend() const noexcept -> select_const_reverse_iterator<L>
     {
-        return xtl::mpl::static_if<L == static_layout>([&](auto self)
-        {
-            return self(*this).derived_cast().linear_crend();
-        }, /*else*/ [&](auto self)
-        {
-            return self(*this).iterable_base::template crend<L>();
-        });
+        return xtl::mpl::static_if<L == static_layout>(
+            [&](auto self)
+            {
+                return self(*this).derived_cast().linear_crend();
+            },
+            /*else*/
+            [&](auto self)
+            {
+                return self(*this).iterable_base::template crend<L>();
+            }
+        );
     }
+
     //@}
 
     /**
      * @name Broadcast iterators
      */
-     /**
-      * Returns an iterator to the first element of the expression. The
-      * iteration is broadcasted to the specified shape.
-      * @param shape the shape used for broadcasting
-      * @tparam S type of the \c shape parameter.
-      * @tparam L order used for the traversal. Default value is \c XTENSOR_DEFAULT_TRAVERSAL.
-      */
+
+    /**
+     * Returns an iterator to the first element of the expression. The
+     * iteration is broadcasted to the specified shape.
+     * @param shape the shape used for broadcasting
+     * @tparam S type of the \c shape parameter.
+     * @tparam L order used for the traversal. Default value is \c XTENSOR_DEFAULT_TRAVERSAL.
+     */
     //@{
     template <class D>
     template <layout_type L, class S>
@@ -1180,7 +1236,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xcontiguous_iterable<D>::cbegin(const S& shape) const noexcept -> const_broadcast_iterator<S, L>
+    inline auto xcontiguous_iterable<D>::cbegin(const S& shape) const noexcept
+        -> const_broadcast_iterator<S, L>
     {
         return iterable_base::template cbegin<L, S>(shape);
     }
@@ -1198,6 +1255,7 @@ namespace xt
     {
         return iterable_base::template cend<L, S>(shape);
     }
+
     //@}
 
     /**
@@ -1241,7 +1299,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xcontiguous_iterable<D>::rbegin(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xcontiguous_iterable<D>::rbegin(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return iterable_base::template rbegin<L, S>(shape);
     }
@@ -1255,7 +1314,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xcontiguous_iterable<D>::rend(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xcontiguous_iterable<D>::rend(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return iterable_base::template rend<L, S>(shape);
     }
@@ -1269,7 +1329,8 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xcontiguous_iterable<D>::crbegin(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xcontiguous_iterable<D>::crbegin(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return iterable_base::template crbegin<L, S>(shape);
     }
@@ -1283,10 +1344,12 @@ namespace xt
      */
     template <class D>
     template <layout_type L, class S>
-    inline auto xcontiguous_iterable<D>::crend(const S& shape) const noexcept -> const_reverse_broadcast_iterator<S, L>
+    inline auto xcontiguous_iterable<D>::crend(const S& shape) const noexcept
+        -> const_reverse_broadcast_iterator<S, L>
     {
         return iterable_base::template crend<L, S>(shape);
     }
+
     //@}
 
     template <class D>
