@@ -1,11 +1,11 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #ifndef XTENSOR_LAYOUT_HPP
 #define XTENSOR_LAYOUT_HPP
@@ -35,15 +35,14 @@ namespace xt
     /**
      * Implementation of the following logical table:
      *
-     * @verbatim
-         | d | a | r | c |
-       --+---+---+---+---+
-       d | d | d | d | d |
-       a | d | a | r | c |
-       r | d | r | r | d |
-       c | d | c | d | c |
-       d = dynamic, a = any, r = row_major, c = column_major.
-       @endverbatim
+     *        | d | a | r | c |
+     *      --+---+---+---+---+
+     *      d | d | d | d | d |
+     *      a | d | a | r | c |
+     *      r | d | r | r | d |
+     *      c | d | c | d | c |
+     *      d = dynamic, a = any, r = row_major, c = column_major.
+     *
      * Using bitmasks to avoid nested if-else statements.
      *
      * @param args the input layouts.
@@ -93,8 +92,7 @@ namespace xt
 
     constexpr layout_type default_assignable_layout(layout_type l) noexcept
     {
-        return (l == layout_type::row_major || l == layout_type::column_major) ?
-            l : XTENSOR_DEFAULT_LAYOUT;
+        return (l == layout_type::row_major || l == layout_type::column_major) ? l : XTENSOR_DEFAULT_LAYOUT;
     }
 
     constexpr layout_type layout_remove_any(const layout_type layout) noexcept
