@@ -1,19 +1,21 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 
+#include <type_traits>
+
 #include "xtensor/xarray.hpp"
-#include "xtensor/xtensor.hpp"
-#include "xtensor/xmanipulation.hpp"
 #include "xtensor/xio.hpp"
+#include "xtensor/xmanipulation.hpp"
+#include "xtensor/xtensor.hpp"
+
 #include "test_common.hpp"
-#include <type_traits>
 
 namespace xt
 {
@@ -258,7 +260,7 @@ namespace xt
         EXPECT_EQ(8, c());
 
         EXPECT_EQ(8, c(1, 2));
-        xindex idx = { 1, 2 };
+        xindex idx = {1, 2};
         EXPECT_EQ(8, c.element(idx.cbegin(), idx.cend()));
     }
 
@@ -276,10 +278,8 @@ namespace xt
 
     TEST(xarray, cross_layout_assign)
     {
-        xarray<int, layout_type::row_major> a = {{1, 2, 3, 4},
-                                                 {5, 6, 7, 8}};
-        xarray<int, layout_type::column_major> b = {{1, 2, 3, 4},
-                                                    {5, 6, 7, 8}};
+        xarray<int, layout_type::row_major> a = {{1, 2, 3, 4}, {5, 6, 7, 8}};
+        xarray<int, layout_type::column_major> b = {{1, 2, 3, 4}, {5, 6, 7, 8}};
 
         xarray<int, layout_type::column_major> ra = a;
         EXPECT_EQ(b, ra);
@@ -296,12 +296,18 @@ namespace xt
 
     TEST(xarray, move_from_xtensor)
     {
-        xtensor<double, 3> a = {{{1,2,3}, {4,5,6}}, {{10, 10, 10}, {1,5,10}}};
+        xtensor<double, 3> a = {{{1, 2, 3}, {4, 5, 6}}, {{10, 10, 10}, {1, 5, 10}}};
         xtensor<double, 3> a1 = a;
         xarray<double> b(std::move(a1));
         EXPECT_EQ(a, b);
-        EXPECT_TRUE(std::equal(a.strides().begin(), a.strides().end(), b.strides().begin()) && a.strides().size() == b.strides().size());
-        EXPECT_TRUE(std::equal(a.backstrides().begin(), a.backstrides().end(), b.backstrides().begin()) && a.backstrides().size() == b.backstrides().size());
+        EXPECT_TRUE(
+            std::equal(a.strides().begin(), a.strides().end(), b.strides().begin())
+            && a.strides().size() == b.strides().size()
+        );
+        EXPECT_TRUE(
+            std::equal(a.backstrides().begin(), a.backstrides().end(), b.backstrides().begin())
+            && a.backstrides().size() == b.backstrides().size()
+        );
         EXPECT_EQ(a.layout(), b.layout());
 
         xtensor<double, 3> a2 = a;
@@ -309,19 +315,25 @@ namespace xt
         c = std::move(a2);
 
         EXPECT_EQ(a, c);
-        EXPECT_TRUE(std::equal(a.strides().begin(), a.strides().end(), c.strides().begin()) && a.strides().size() == c.strides().size());
-        EXPECT_TRUE(std::equal(a.backstrides().begin(), a.backstrides().end(), c.backstrides().begin()) && a.backstrides().size() == c.backstrides().size());
+        EXPECT_TRUE(
+            std::equal(a.strides().begin(), a.strides().end(), c.strides().begin())
+            && a.strides().size() == c.strides().size()
+        );
+        EXPECT_TRUE(
+            std::equal(a.backstrides().begin(), a.backstrides().end(), c.backstrides().begin())
+            && a.backstrides().size() == c.backstrides().size()
+        );
         EXPECT_EQ(a.layout(), c.layout());
     }
 
     TEST(xarray, operator_brace)
     {
 #ifdef XTENSOR_ENABLE_ASSERT
-        xt::xarray<size_t> a = {{0,1,2}, {3,4,5}};
+        xt::xarray<size_t> a = {{0, 1, 2}, {3, 4, 5}};
         EXPECT_THROW(a(2, 0), std::runtime_error);
         EXPECT_THROW(a(0, 3), std::runtime_error);
 
-        xt::xarray<size_t> b = {{0,1,2}};
+        xt::xarray<size_t> b = {{0, 1, 2}};
         EXPECT_THROW(a(0, 3), std::runtime_error);
         EXPECT_THROW(a(1, 3), std::runtime_error);
 #endif
@@ -329,31 +341,31 @@ namespace xt
 
     TEST(xarray, periodic)
     {
-        xt::xarray<size_t> a = {{0,1,2}, {3,4,5}};
-        xt::xarray<size_t> b = {{0,1,2}, {30,40,50}};
-        a.periodic(-1,3) = 30;
-        a.periodic(-1,4) = 40;
-        a.periodic(-1,5) = 50;
+        xt::xarray<size_t> a = {{0, 1, 2}, {3, 4, 5}};
+        xt::xarray<size_t> b = {{0, 1, 2}, {30, 40, 50}};
+        a.periodic(-1, 3) = 30;
+        a.periodic(-1, 4) = 40;
+        a.periodic(-1, 5) = 50;
         EXPECT_EQ(a, b);
     }
 
     TEST(xarray, front)
     {
-        xt::xarray<size_t> a = {{1,2,3}, {4,5,6}};
+        xt::xarray<size_t> a = {{1, 2, 3}, {4, 5, 6}};
         EXPECT_EQ(a.front(), 1);
     }
 
     TEST(xarray, back)
     {
-        xt::xarray<size_t> a = {{1,2,3}, {4,5,6}};
+        xt::xarray<size_t> a = {{1, 2, 3}, {4, 5, 6}};
         EXPECT_EQ(a.back(), 6);
     }
 
-TEST(xarray, flat)
+    TEST(xarray, flat)
     {
         {
-            xt::xarray<size_t, xt::layout_type::row_major> a = {{0,1,2}, {3,4,5}};
-            xt::xarray<size_t, xt::layout_type::row_major> b = {{0,1,2}, {30,40,50}};
+            xt::xarray<size_t, xt::layout_type::row_major> a = {{0, 1, 2}, {3, 4, 5}};
+            xt::xarray<size_t, xt::layout_type::row_major> b = {{0, 1, 2}, {30, 40, 50}};
             a.flat(3) = 30;
             a.flat(4) = 40;
             a.flat(5) = 50;
@@ -363,8 +375,8 @@ TEST(xarray, flat)
 #endif
         }
         {
-            xt::xarray<size_t, xt::layout_type::column_major> a = {{0,1,2}, {3,4,5}};
-            xt::xarray<size_t, xt::layout_type::column_major> b = {{0,1,2}, {30,40,50}};
+            xt::xarray<size_t, xt::layout_type::column_major> a = {{0, 1, 2}, {3, 4, 5}};
+            xt::xarray<size_t, xt::layout_type::column_major> b = {{0, 1, 2}, {30, 40, 50}};
             a.flat(1) = 30;
             a.flat(3) = 40;
             a.flat(5) = 50;
@@ -377,9 +389,9 @@ TEST(xarray, flat)
 
     TEST(xarray, in_bounds)
     {
-        xt::xarray<size_t> a = {{0,1,2}, {3,4,5}};
-        EXPECT_TRUE(a.in_bounds(0,0) == true);
-        EXPECT_TRUE(a.in_bounds(2,0) == false);
+        xt::xarray<size_t> a = {{0, 1, 2}, {3, 4, 5}};
+        EXPECT_TRUE(a.in_bounds(0, 0) == true);
+        EXPECT_TRUE(a.in_bounds(2, 0) == false);
     }
 
     TEST(xarray, iterator_types)
@@ -388,7 +400,8 @@ TEST(xarray, flat)
         test_iterator_types<array_type, int*, const int*>();
     }
 
-    auto test_reshape_compile() {
+    auto test_reshape_compile()
+    {
         xt::xarray<double> a = xt::zeros<double>({5, 5});
         return a.reshape({1, 25});
     }
