@@ -1,23 +1,23 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
-#include "test_common_macros.hpp"
 #include "xtensor/xarray.hpp"
 #include "xtensor/xbuilder.hpp"
+#include "xtensor/xdynamic_view.hpp"
+#include "xtensor/xindex_view.hpp"
 #include "xtensor/xio.hpp"
 #include "xtensor/xnoalias.hpp"
-#include "xtensor/xdynamic_view.hpp"
-#include "xtensor/xtensor.hpp"
 #include "xtensor/xrandom.hpp"
-
+#include "xtensor/xtensor.hpp"
 #include "xtensor/xview.hpp"
-#include "xtensor/xindex_view.hpp"
+
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -26,14 +26,12 @@ namespace xt
 
     TEST(xdynamic_view, keep)
     {
-        xarray<int> a = { {{0, 1, 2, 3},
-                           {4, 5, 6, 7},
-                           {8, 9, 10, 11}},
-                          {{12, 13, 14, 15},
-                           {16, 17, 18, 19},
-                           {20, 21, 22, 23}} };
+        xarray<int> a = {
+            {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
-        auto view0 = dynamic_view(a, xdynamic_slice_vector({ 1, keep(0, 2), range(1, 4) }));
+        auto view0 = dynamic_view(a, xdynamic_slice_vector({1, keep(0, 2), range(1, 4)}));
         EXPECT_EQ(view0.dimension(), size_t(2));
         EXPECT_EQ(view0.shape()[0], size_t(2));
         EXPECT_EQ(view0.shape()[1], size_t(3));
@@ -44,7 +42,7 @@ namespace xt
         EXPECT_EQ(view0(1, 1), a(1, 2, 2));
         EXPECT_EQ(view0(1, 2), a(1, 2, 3));
 
-        auto view1 = dynamic_view(a, xdynamic_slice_vector({ all(), 1, keep(0, 2, 3) }));
+        auto view1 = dynamic_view(a, xdynamic_slice_vector({all(), 1, keep(0, 2, 3)}));
         EXPECT_EQ(view1.dimension(), size_t(2));
         EXPECT_EQ(view1.shape()[0], size_t(2));
         EXPECT_EQ(view1.shape()[1], size_t(3));
@@ -55,10 +53,10 @@ namespace xt
         EXPECT_EQ(view1(1, 1), a(1, 1, 2));
         EXPECT_EQ(view1(1, 2), a(1, 1, 3));
 
-        auto view2 = dynamic_view(a, { all(), 1, keep(0, 2, 3) });
+        auto view2 = dynamic_view(a, {all(), 1, keep(0, 2, 3)});
         EXPECT_EQ(view1, view2);
 
-        auto view3 = dynamic_view(a, { all(), 1, newaxis(), keep(0, 2, 3) });
+        auto view3 = dynamic_view(a, {all(), 1, newaxis(), keep(0, 2, 3)});
         EXPECT_EQ(view3.dimension(), size_t(3));
         EXPECT_EQ(view3.shape()[0], size_t(2));
         EXPECT_EQ(view3.shape()[1], size_t(1));
@@ -70,23 +68,21 @@ namespace xt
         EXPECT_EQ(view3(1, 0, 1), a(1, 1, 2));
         EXPECT_EQ(view3(1, 0, 2), a(1, 1, 3));
 
-        auto view4 = dynamic_view(a, { 1, keep(0, 2), xrange<std::ptrdiff_t>(1, 4) });
+        auto view4 = dynamic_view(a, {1, keep(0, 2), xrange<std::ptrdiff_t>(1, 4)});
         EXPECT_EQ(view0, view4);
 
-        auto view5 = dynamic_view(a, { 1, keep(0, 2), xstepped_range<std::ptrdiff_t>(1, 4, 1) });
+        auto view5 = dynamic_view(a, {1, keep(0, 2), xstepped_range<std::ptrdiff_t>(1, 4, 1)});
         EXPECT_EQ(view0, view5);
     }
 
     TEST(xdynamic_view, keep_iterator)
     {
-        xarray<int> a = { {{0, 1, 2, 3},
-                           {4, 5, 6, 7},
-                           {8, 9, 10, 11}},
-                          {{12, 13, 14, 15},
-                           {16, 17, 18, 19},
-                           {20, 21, 22, 23}} };
+        xarray<int> a = {
+            {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
-        auto view0 = dynamic_view(a, xdynamic_slice_vector({ 1, keep(0, 2), range(1, 4) }));
+        auto view0 = dynamic_view(a, xdynamic_slice_vector({1, keep(0, 2), range(1, 4)}));
         auto iter = view0.template begin<layout_type::row_major>();
         auto iter_end = view0.template end<layout_type::row_major>();
 
@@ -107,14 +103,12 @@ namespace xt
 
     TEST(xdynamic_view, drop)
     {
-        xarray<int> a = { {{0, 1, 2, 3},
-                           {4, 5, 6, 7},
-                           {8, 9, 10, 11}},
-                          {{12, 13, 14, 15},
-                           {16, 17, 18, 19},
-                           {20, 21, 22, 23}} };
+        xarray<int> a = {
+            {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
-        auto view0 = dynamic_view(a, xdynamic_slice_vector({ 1, drop(1), range(1, 4) }));
+        auto view0 = dynamic_view(a, xdynamic_slice_vector({1, drop(1), range(1, 4)}));
         EXPECT_EQ(view0.dimension(), size_t(2));
         EXPECT_EQ(view0.shape()[0], size_t(2));
         EXPECT_EQ(view0.shape()[1], size_t(3));
@@ -125,7 +119,7 @@ namespace xt
         EXPECT_EQ(view0(1, 1), a(1, 2, 2));
         EXPECT_EQ(view0(1, 2), a(1, 2, 3));
 
-        auto view1 = dynamic_view(a, xdynamic_slice_vector({ all(), 1, drop(1, 2) }));
+        auto view1 = dynamic_view(a, xdynamic_slice_vector({all(), 1, drop(1, 2)}));
         EXPECT_EQ(view1.dimension(), size_t(2));
         EXPECT_EQ(view1.shape()[0], size_t(2));
         EXPECT_EQ(view1.shape()[1], size_t(2));
@@ -134,7 +128,7 @@ namespace xt
         EXPECT_EQ(view1(1, 0), a(1, 1, 0));
         EXPECT_EQ(view1(1, 1), a(1, 1, 3));
 
-        auto view3 = dynamic_view(a, { all(), 1, newaxis(), drop(1, 2) });
+        auto view3 = dynamic_view(a, {all(), 1, newaxis(), drop(1, 2)});
         EXPECT_EQ(view3.dimension(), size_t(3));
         EXPECT_EQ(view3.shape()[0], size_t(2));
         EXPECT_EQ(view3.shape()[1], size_t(1));
@@ -147,14 +141,12 @@ namespace xt
 
     TEST(xdynamic_view, drop_iterator)
     {
-        xarray<int> a = { {{0, 1, 2, 3},
-                           {4, 5, 6, 7},
-                           {8, 9, 10, 11}},
-                          {{12, 13, 14, 15},
-                           {16, 17, 18, 19},
-                           {20, 21, 22, 23}} };
+        xarray<int> a = {
+            {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
-        auto view0 = dynamic_view(a, xdynamic_slice_vector({ 1, drop(1), range(1, 4) }));
+        auto view0 = dynamic_view(a, xdynamic_slice_vector({1, drop(1), range(1, 4)}));
         auto iter = view0.template begin<layout_type::row_major>();
         auto iter_end = view0.template end<layout_type::row_major>();
 
@@ -175,17 +167,15 @@ namespace xt
 
     TEST(xdynamic_view, semantic)
     {
-        xarray<int> a = { {{0, 1, 2, 3},
-                           {4, 5, 6, 7},
-                           {8, 9, 10, 11}},
-                          {{12, 13, 14, 15},
-                           {16, 17, 18, 19},
-                           {20, 21, 22, 23}} };
+        xarray<int> a = {
+            {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
-        xarray<int> b1 = { {13, 14, 15}, {21, 22, 23} };
-        xarray<int> b2 = { {0, 1, 2}, {3, 4, 5} };
+        xarray<int> b1 = {{13, 14, 15}, {21, 22, 23}};
+        xarray<int> b2 = {{0, 1, 2}, {3, 4, 5}};
         xarray<int> exp = b1 + b2;
-        auto view0 = dynamic_view(a, { 1, keep(0, 2), range(1, 4) });
+        auto view0 = dynamic_view(a, {1, keep(0, 2), range(1, 4)});
         view0 += b2;
         EXPECT_EQ(view0, exp);
     }
@@ -214,7 +204,7 @@ namespace xt
         EXPECT_EQ(as.size(), 11);
         EXPECT_EQ(as(0), 0);
 
-        auto as2  = au.convert<std::ptrdiff_t>();
+        auto as2 = au.convert<std::ptrdiff_t>();
         EXPECT_EQ(as2, as);
 
         xnewaxis<std::size_t> nau;
@@ -225,7 +215,7 @@ namespace xt
         auto nas2 = nau.convert<std::ptrdiff_t>();
         EXPECT_EQ(nas2, nas);
 
-        xkeep_slice<std::ptrdiff_t> ks({ 2, 3, -1 });
+        xkeep_slice<std::ptrdiff_t> ks({2, 3, -1});
         ks.normalize(6);
         xkeep_slice<std::size_t> ku(ks);
         EXPECT_EQ(ku.size(), std::size_t(3));
@@ -239,7 +229,7 @@ namespace xt
         auto ks2 = ku.convert<std::size_t>();
         EXPECT_EQ(ks2, ks);
 
-        xdrop_slice<std::ptrdiff_t> ds({ 2, 3, -1 });
+        xdrop_slice<std::ptrdiff_t> ds({2, 3, -1});
         ds.normalize(6);
         xdrop_slice<std::size_t> du(ds);
         EXPECT_EQ(du.size(), std::size_t(3));
@@ -258,7 +248,7 @@ namespace xt
     {
         xt::xarray<float> array(xt::random::rand<float>({5, 4}));
         auto v = xt::view(array, xt::keep(2), xt::all());
-        auto res  = xt::xarray<float>(xt::dynamic_view(v, {xt::keep(0)}));
+        auto res = xt::xarray<float>(xt::dynamic_view(v, {xt::keep(0)}));
         EXPECT_EQ(res(1), array(2, 1));
     }
 
