@@ -1,19 +1,20 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
-#include "test_common_macros.hpp"
 #include "xtensor/xarray.hpp"
-#include "xtensor/xview.hpp"
-#include "test_common.hpp"
-#include "xtensor/xtensor.hpp"
-#include "xtensor/xrandom.hpp"
 #include "xtensor/xfixed.hpp"
+#include "xtensor/xrandom.hpp"
+#include "xtensor/xtensor.hpp"
+#include "xtensor/xview.hpp"
+
+#include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -57,16 +58,16 @@ namespace xt
         }
     }
 
-    template<typename E>
+    template <typename E>
     auto normalize(E&& expr)
     {
-        return E{ expr } / xt::view(xt::sum(E{ expr }, { 1 }), xt::all(), xt::newaxis());
+        return E{expr} / xt::view(xt::sum(E{expr}, {1}), xt::all(), xt::newaxis());
     }
 
     TEST(xfunction, copy_constructor)
     {
-        xt::xarray<double> freqs({ 10, 5 }, 1);
-        xt::xarray<double> other_freqs({ 10, 5 }, 2);
+        xt::xarray<double> freqs({10, 5}, 1);
+        xt::xarray<double> other_freqs({10, 5}, 2);
         // Compilation test
         xarray<double> probs = normalize(freqs + other_freqs);
     }
@@ -103,8 +104,8 @@ namespace xt
 
     TEST(xfunction, broadcast_shape_exception)
     {
-        xt::xarray<double> arr1{ { 1.0, 2.0, 3.0 } };
-        xt::xarray<double> arr2{ 5.0, 6.0, 7.0, 99.0 };
+        xt::xarray<double> arr1{{1.0, 2.0, 3.0}};
+        xt::xarray<double> arr2{5.0, 6.0, 7.0, 99.0};
         XT_EXPECT_ANY_THROW(xt::xarray<double> res = arr1 * arr2);
     }
 
@@ -113,7 +114,7 @@ namespace xt
         xfunction_features f;
         auto func = f.m_a + f.m_c;
         const auto& sh = func.shape();
-        for(std::size_t i = 0; i < sh.size(); ++i)
+        for (std::size_t i = 0; i < sh.size(); ++i)
         {
             EXPECT_EQ(sh[i], func.shape(i));
         }
@@ -433,13 +434,17 @@ namespace xt
         auto res5 = func;
 
         auto resit1 = res1.template begin<XTENSOR_DEFAULT_LAYOUT>();
-        for (auto it = func.template begin<XTENSOR_DEFAULT_LAYOUT>(); it != func.template end<XTENSOR_DEFAULT_LAYOUT>(); ++it)
+        for (auto it = func.template begin<XTENSOR_DEFAULT_LAYOUT>();
+             it != func.template end<XTENSOR_DEFAULT_LAYOUT>();
+             ++it)
         {
             *(resit1++) = *it;
         }
 
         auto resit3 = res3.template rbegin<XTENSOR_DEFAULT_LAYOUT>();
-        for (auto it = func.template rbegin<XTENSOR_DEFAULT_LAYOUT>(); it != func.template rend<XTENSOR_DEFAULT_LAYOUT>(); ++it)
+        for (auto it = func.template rbegin<XTENSOR_DEFAULT_LAYOUT>();
+             it != func.template rend<XTENSOR_DEFAULT_LAYOUT>();
+             ++it)
         {
             *(resit3++) = *it;
         }
@@ -493,9 +498,9 @@ namespace xt
     TEST(xfunction, xfunction_in_xfunction)
     {
         using Point3 = xt::xtensor_fixed<double, xshape<3>>;
-        Point3 a1({1.,2.,3.});
-        Point3 a2({3.,1.,3.});
-        Point3 a3({54.,5.,5.});
+        Point3 a1({1., 2., 3.});
+        Point3 a2({3., 1., 3.});
+        Point3 a3({54., 5., 5.});
         xtensor<Point3, 1> a({a1, a2, a3});
         xtensor<Point3, 1> c = a + a;
         Point3 r1({2., 4., 6.}), r2({6., 2., 6.}), r3({108., 10., 10.});
