@@ -1,20 +1,21 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
-#include "test_common_macros.hpp"
-#include "xtensor/xarray.hpp"
 #include "xtensor/xadapt.hpp"
-#include "xtensor/xrandom.hpp"
-#include "xtensor/xindex_view.hpp"
+#include "xtensor/xarray.hpp"
 #include "xtensor/xbroadcast.hpp"
+#include "xtensor/xindex_view.hpp"
+#include "xtensor/xrandom.hpp"
 #include "xtensor/xview.hpp"
+
 #include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -41,7 +42,7 @@ namespace xt
         EXPECT_EQ(expected, e(1, 1));
 
         auto t = v + 3;
-		EXPECT_DOUBLE_EQ((e_copy(1, 1) + 6), t(0));
+        EXPECT_DOUBLE_EQ((e_copy(1, 1) + 6), t(0));
         EXPECT_EQ((e(1, 1) + 3), t(0));
 
         v = broadcast(123, v.shape());
@@ -55,6 +56,15 @@ namespace xt
         EXPECT_EQ(3, e(2, 2));
     }
 
+    TEST(xindex_view, indices_const)
+    {
+        const xarray<double> e = xt::random::rand<double>({3, 3});
+        auto v = index_view(e, {{1ul, 1ul}, {1ul, 2ul}, {2ul, 2ul}});
+        EXPECT_EQ(e(1, 1), v(0));
+        const auto vc = index_view(e, {{1ul, 1ul}, {1ul, 2ul}, {2ul, 2ul}});
+        EXPECT_EQ(vc(0), v(0));
+    }
+
     TEST(xindex_view, boolean)
     {
         xarray<double> e = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
@@ -77,7 +87,7 @@ namespace xt
 
     TEST(xindex_view, access)
     {
-        xarray<double> e = {{ 1, 0, 0 }, { 0, 1, 0 }, { 0, 0, 1 }};
+        xarray<double> e = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
         auto v = filter(e, e > 0);
         EXPECT_EQ(v(), v(0));
         EXPECT_EQ(v(1, 2, 1), v(1));
@@ -85,8 +95,8 @@ namespace xt
 
     TEST(xindex_view, fill)
     {
-        xarray<double> e = { { 1, 0, 0 },{ 0, 1, 0 },{ 0, 0, 1 } };
-        xarray<double> res = { {1, 2, 2}, {2, 1, 2}, {2, 2, 1} };
+        xarray<double> e = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
+        xarray<double> res = {{1, 2, 2}, {2, 1, 2}, {2, 2, 1}};
         auto v = filter(e, e < 1);
         v.fill(2);
         EXPECT_EQ(e, res);
@@ -94,7 +104,7 @@ namespace xt
 
     TEST(xindex_view, unchecked)
     {
-        xarray<double> e = { { 1, 0, 0 },{ 0, 1, 0 },{ 0, 0, 1 } };
+        xarray<double> e = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
         auto v = filter(e, e > 0);
         EXPECT_EQ(v.unchecked(1), v(1));
     }
@@ -147,10 +157,10 @@ namespace xt
 
     TEST(xindex_view, filter)
     {
-        xarray<double> a = {{ 1, 5, 3 },{ 4, 5, 6 }};
-        const xarray<double> b = {{ 1, 5, 3 },{ 4, 5, 6 }};
+        xarray<double> a = {{1, 5, 3}, {4, 5, 6}};
+        const xarray<double> b = {{1, 5, 3}, {4, 5, 6}};
         filter(a, a > 3) += filter(b, b > 3);
-        xarray<double> expected = {{ 1, 10, 3}, {8, 10, 12}};
+        xarray<double> expected = {{1, 10, 3}, {8, 10, 12}};
         EXPECT_EQ(expected, a);
     }
 
@@ -158,19 +168,19 @@ namespace xt
     {
         xarray<int> a = {{{1, 3}, {2, 4}}, {{5, 7}, {6, 8}}};
         xarray<bool> cond = {{{true, true}, {false, false}}, {{true, true}, {false, false}}};
-        
+
         xarray<int> resc = xt::filter<xt::layout_type::column_major>(a, cond);
-        xarray<int> expc = {1, 5 ,3, 7};
+        xarray<int> expc = {1, 5, 3, 7};
         EXPECT_EQ(resc, expc);
 
         xarray<int> resr = xt::filter(a, cond);
-        xarray<int> expr = {1, 3 ,5, 7};
+        xarray<int> expr = {1, 3, 5, 7};
         EXPECT_EQ(resr, expr);
     }
 
     TEST(xindex_view, const_adapt_filter)
     {
-        const std::vector<double> av({1,2,3,4,5,6});
+        const std::vector<double> av({1, 2, 3, 4, 5, 6});
         auto a = xt::adapt(av, std::array<std::size_t, 2>({3, 2}));
         xt::xarray<double> b = {{1, 2, 3}, {4, 5, 6}};
         xt::filter(b, b > 3) += xt::filter(a, a < 4);
