@@ -1,18 +1,17 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
-
-#include "test_common_macros.hpp"
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #include "xtensor/xarray.hpp"
 #include "xtensor/xtensor.hpp"
 
 #include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -35,10 +34,16 @@ namespace xt
         xarray_adaptor<typename R::vector_type, layout_type::dynamic> a(data, result.shape(), result.strides());
 
         auto offset = shape.size() - a.dimension();
-        auto broadcasting_stride = std::accumulate(shape.cbegin(), shape.cbegin() + offset, size_type(1), std::multiplies<size_type>());
-        size_type nb_inc = (L == layout_type::row_major ?
-            shape.back() * shape[shape.size() - 2] + 1 :
-            broadcasting_stride * (result.shape().front() * result.shape()[1] + 1));
+        auto broadcasting_stride = std::accumulate(
+            shape.cbegin(),
+            shape.cbegin() + offset,
+            size_type(1),
+            std::multiplies<size_type>()
+        );
+        size_type nb_inc =
+            (L == layout_type::row_major
+                 ? shape.back() * shape[shape.size() - 2] + 1
+                 : broadcasting_stride * (result.shape().front() * result.shape()[1] + 1));
 
         int expected = a(1, 0, 1);
 
@@ -50,8 +55,8 @@ namespace xt
             iter2++;
         }
 
-        CHECK_MESSAGE(*iter==expected, "preincrement operator doesn't give expected result");
-        CHECK_MESSAGE(*iter2==expected, "postincrement operator doesn't give expected result");
+        CHECK_MESSAGE(*iter == expected, "preincrement operator doesn't give expected result");
+        CHECK_MESSAGE(*iter2 == expected, "postincrement operator doesn't give expected result");
     }
 
     template <layout_type L, class R, class S>
@@ -63,10 +68,16 @@ namespace xt
         xarray_adaptor<typename R::vector_type, layout_type::dynamic> a(data, result.shape(), result.strides());
 
         auto offset = shape.size() - a.dimension();
-        auto broadcasting_stride = std::accumulate(shape.cbegin(), shape.cbegin() + offset, difference_type(1), std::multiplies<difference_type>());
-        auto nb_inc = L == layout_type::row_major ?
-            difference_type(shape.back() * shape[shape.size() - 2] + 1) :
-            broadcasting_stride * difference_type(result.shape().front() * result.shape()[1] + 1);
+        auto broadcasting_stride = std::accumulate(
+            shape.cbegin(),
+            shape.cbegin() + offset,
+            difference_type(1),
+            std::multiplies<difference_type>()
+        );
+        auto nb_inc = L == layout_type::row_major
+                          ? difference_type(shape.back() * shape[shape.size() - 2] + 1)
+                          : broadcasting_stride
+                                * difference_type(result.shape().front() * result.shape()[1] + 1);
 
         int expected = a(1, 0, 1);
 
@@ -77,11 +88,9 @@ namespace xt
         auto iter3 = iter2 + nb_inc;
 
 
-
-        CHECK_MESSAGE(*iter==expected,  "preincrement operator doesn't give expected result");
-        CHECK_MESSAGE(*iter3==expected,  "postincrement operator doesn't give expected result");
-        CHECK_MESSAGE(iter2[nb_inc]==expected,  "postincrement operator doesn't give expected result");
-
+        CHECK_MESSAGE(*iter == expected, "preincrement operator doesn't give expected result");
+        CHECK_MESSAGE(*iter3 == expected, "postincrement operator doesn't give expected result");
+        CHECK_MESSAGE(iter2[nb_inc] == expected, "postincrement operator doesn't give expected result");
     }
 
     template <layout_type L, class R, class S>
@@ -100,7 +109,7 @@ namespace xt
             ++iter;
         }
 
-        CHECK_MESSAGE(iter==last, "iterator doesn't reach the end");
+        CHECK_MESSAGE(iter == last, "iterator doesn't reach the end");
         EXPECT_FALSE(iter < last);
     }
 
@@ -113,10 +122,16 @@ namespace xt
         xarray_adaptor<typename R::vector_type, layout_type::dynamic> a(data, result.shape(), result.strides());
 
         auto offset = shape.size() - a.dimension();
-        auto broadcasting_stride = std::accumulate(shape.cbegin(), shape.cbegin() + offset, size_type(1), std::multiplies<size_type>());
-        size_type nb_inc = (L == layout_type::row_major ?
-            shape.back() * shape[shape.size() - 2] + 1 :
-            broadcasting_stride * (result.shape().front() * result.shape()[1] + 1));
+        auto broadcasting_stride = std::accumulate(
+            shape.cbegin(),
+            shape.cbegin() + offset,
+            size_type(1),
+            std::multiplies<size_type>()
+        );
+        size_type nb_inc =
+            (L == layout_type::row_major
+                 ? shape.back() * shape[shape.size() - 2] + 1
+                 : broadcasting_stride * (result.shape().front() * result.shape()[1] + 1));
 
         int expected = a(1, 1, 2);
 
@@ -140,11 +155,17 @@ namespace xt
         xarray_adaptor<typename R::vector_type, layout_type::dynamic> a(data, result.shape(), result.strides());
 
         auto offset = shape.size() - a.dimension();
-        auto broadcasting_stride = std::accumulate(shape.cbegin(), shape.cbegin() + offset, difference_type(1), std::multiplies<difference_type>());
-        
-        auto nb_inc = L == layout_type::row_major ?
-            difference_type(shape.back() * shape[shape.size() - 2] + 1) :
-            broadcasting_stride * difference_type(result.shape().front() * result.shape()[1] + 1);
+        auto broadcasting_stride = std::accumulate(
+            shape.cbegin(),
+            shape.cbegin() + offset,
+            difference_type(1),
+            std::multiplies<difference_type>()
+        );
+
+        auto nb_inc = L == layout_type::row_major
+                          ? difference_type(shape.back() * shape[shape.size() - 2] + 1)
+                          : broadcasting_stride
+                                * difference_type(result.shape().front() * result.shape()[1] + 1);
 
         int expected = a(1, 1, 2);
 
@@ -154,8 +175,8 @@ namespace xt
         iter += nb_inc;
         auto iter3 = iter2 + nb_inc;
 
-        CHECK_MESSAGE(*iter == expected , "predecrement operator doesn't give expected result");
-        CHECK_MESSAGE(*iter3 == expected , "postdecrement operator doesn't give expected result");
+        CHECK_MESSAGE(*iter == expected, "predecrement operator doesn't give expected result");
+        CHECK_MESSAGE(*iter3 == expected, "postdecrement operator doesn't give expected result");
     }
 
     template <layout_type L, class R, class S>
@@ -170,22 +191,19 @@ namespace xt
         auto iter = a.template rbegin<L>(shape);
         auto last = a.template rend<L>(shape);
 
-        CHECK_MESSAGE(*iter==data.back(), "dereferencing rbegin does not result in last element");
-        CHECK_MESSAGE(*last==data.front(), "dereferencing rend does not result in first element");
+        CHECK_MESSAGE(*iter == data.back(), "dereferencing rbegin does not result in last element");
+        CHECK_MESSAGE(*last == data.front(), "dereferencing rend does not result in first element");
 
         for (size_type i = 0; i < size; ++i)
         {
             ++iter;
         }
 
-        CHECK_MESSAGE(iter==last, "reverse iterator doesn't reach the end");
+        CHECK_MESSAGE(iter == last, "reverse iterator doesn't reach the end");
     }
 
-    #define XITERATOR_TEST_TYPES\
-        row_major_result<>,\
-        column_major_result<>,\
-        central_major_result<>,\
-        unit_shape_result<>
+#define XITERATOR_TEST_TYPES \
+    row_major_result<>, column_major_result<>, central_major_result<>, unit_shape_result<>
 
     TEST_SUITE("xiterator_test")
     {
@@ -380,8 +398,6 @@ namespace xt
         }
     }
 
-
-
     template <layout_type L, class R, class S>
     void test_minus(const R& result, const S& shape)
     {
@@ -390,14 +406,16 @@ namespace xt
         using vector_type = typename R::vector_type;
         vector_type data = result.storage();
         xarray_adaptor<typename R::vector_type, layout_type::dynamic> a(data, result.shape(), result.strides());
-        
+
         size_type size = shape.size();
-        difference_type nb_inc = difference_type(L == layout_type::row_major ?
-            shape.back() * shape[size - 2] + shape.back() + 2 :
-            shape[size - 3] * shape[size - 2] * 2 + shape[size - 3] + 1);
-        difference_type nb_inc2 = difference_type(L == layout_type::row_major ?
-            shape.back() * shape[size - 2] * 2  + 3 :
-            shape[size - 3] * shape[size - 2] * 3 + 2);
+        difference_type nb_inc = difference_type(
+            L == layout_type::row_major ? shape.back() * shape[size - 2] + shape.back() + 2
+                                        : shape[size - 3] * shape[size - 2] * 2 + shape[size - 3] + 1
+        );
+        difference_type nb_inc2 = difference_type(
+            L == layout_type::row_major ? shape.back() * shape[size - 2] * 2 + 3
+                                        : shape[size - 3] * shape[size - 2] * 3 + 2
+        );
 
         ptrdiff_t expected = ptrdiff_t(nb_inc2 - nb_inc);
 
@@ -452,17 +470,18 @@ namespace xt
 
     TEST(xiterator, broadcast)
     {
-        EXPECT_TRUE(broadcastable(std::vector<size_t>({1, 2, 1}), std::vector<size_t>({ 3, 2, 1 })));
-        EXPECT_TRUE(broadcastable(std::vector<size_t>({1, 1}), std::vector<size_t>({ 3, 2, 1 })));
+        EXPECT_TRUE(broadcastable(std::vector<size_t>({1, 2, 1}), std::vector<size_t>({3, 2, 1})));
+        EXPECT_TRUE(broadcastable(std::vector<size_t>({1, 1}), std::vector<size_t>({3, 2, 1})));
         EXPECT_TRUE(broadcastable(std::vector<size_t>({1, 1}), std::vector<size_t>({2, 2, 1})));
-        EXPECT_FALSE(broadcastable(std::vector<size_t>({2, 2, 1}), std::vector<size_t>({ 3, 2, 1 })));
+        EXPECT_FALSE(broadcastable(std::vector<size_t>({2, 2, 1}), std::vector<size_t>({3, 2, 1})));
     }
 
     TEST(xiterator, pointer)
     {
-        xarray<double> m {{3, 4}, {6, 5}};
-        constexpr layout_type l = xarray<double>::static_layout == layout_type::column_major ?
-            layout_type::row_major : layout_type::column_major;
+        xarray<double> m{{3, 4}, {6, 5}};
+        constexpr layout_type l = xarray<double>::static_layout == layout_type::column_major
+                                      ? layout_type::row_major
+                                      : layout_type::column_major;
         auto it = m.begin<l>();
         EXPECT_EQ(*(it.operator->()), 3);
     }
@@ -509,18 +528,26 @@ namespace xt
         row_major_result<> rm;
         using vector_type = row_major_result<>::vector_type;
         xarray_adaptor<vector_type, layout_type::dynamic> a(rm.storage(), rm.shape(), rm.strides());
-        
+
         SUBCASE("row_major iterator")
         {
             xarray<vector_type::value_type> dst(a.shape(), 1);
-            std::copy(a.cbegin<layout_type::row_major>(), a.cend<layout_type::row_major>(), dst.begin<layout_type::row_major>());
+            std::copy(
+                a.cbegin<layout_type::row_major>(),
+                a.cend<layout_type::row_major>(),
+                dst.begin<layout_type::row_major>()
+            );
             EXPECT_EQ(a, dst);
         }
 
         SUBCASE("column_major iterator")
         {
             xarray<vector_type::value_type> dst(a.shape(), 1);
-            std::copy(a.cbegin<layout_type::column_major>(), a.cend<layout_type::column_major>(), dst.begin<layout_type::column_major>());
+            std::copy(
+                a.cbegin<layout_type::column_major>(),
+                a.cend<layout_type::column_major>(),
+                dst.begin<layout_type::column_major>()
+            );
             EXPECT_EQ(a, dst);
         }
     }
@@ -534,23 +561,29 @@ namespace xt
         SUBCASE("row_major iterator")
         {
             xarray<vector_type::value_type> dst(a.shape(), 1);
-            std::copy(a.crbegin<layout_type::row_major>(), a.crend<layout_type::row_major>(), dst.rbegin<layout_type::row_major>());
+            std::copy(
+                a.crbegin<layout_type::row_major>(),
+                a.crend<layout_type::row_major>(),
+                dst.rbegin<layout_type::row_major>()
+            );
             EXPECT_EQ(a, dst);
         }
 
         SUBCASE("column_major iterator")
         {
             xarray<vector_type::value_type> dst(a.shape(), 1);
-            std::copy(a.crbegin<layout_type::column_major>(), a.crend<layout_type::column_major>(), dst.rbegin<layout_type::column_major>());
+            std::copy(
+                a.crbegin<layout_type::column_major>(),
+                a.crend<layout_type::column_major>(),
+                dst.rbegin<layout_type::column_major>()
+            );
             EXPECT_EQ(a, dst);
         }
     }
 
     TEST(xiterator, reverse_corner_cases)
     {
-        xtensor<double, 3> a = {{{13, 16},
-                                 {13, 16},
-                                 {13, 16}}};
+        xtensor<double, 3> a = {{{13, 16}, {13, 16}, {13, 16}}};
 
         constexpr auto cm = layout_type::column_major;
         constexpr auto rm = layout_type::row_major;
@@ -597,14 +630,9 @@ namespace xt
             }
         }
 
-        xtensor<double, 3> b = {{{1},
-                                 {1}},
-                                {{2},
-                                 {2}},
-                                {{3},
-                                 {3}}};
+        xtensor<double, 3> b = {{{1}, {1}}, {{2}, {2}}, {{3}, {3}}};
 
-       {
+        {
             std::vector<double> exp_iter = {3, 2, 1, 3, 2, 1};
             auto e_iter = exp_iter.begin();
             for (auto it = b.template rbegin<cm>(); it != b.template rend<cm>(); ++it)
@@ -613,9 +641,9 @@ namespace xt
                 ++e_iter;
             }
             EXPECT_TRUE(e_iter == exp_iter.end());
-       }
+        }
 
-       {
+        {
             std::vector<double> exp_iter = {3, 3, 2, 2, 1, 1};
             auto e_iter = exp_iter.begin();
             for (auto it = b.template rbegin<rm>(); it != b.template rend<rm>(); ++it)
@@ -624,9 +652,9 @@ namespace xt
                 ++e_iter;
             }
             EXPECT_TRUE(e_iter == exp_iter.end());
-       }
+        }
 
-       {
+        {
             std::vector<double> exp_iter = {1, 1, 2, 2, 3, 3};
             auto e_iter = exp_iter.begin();
             for (auto it = b.template begin<rm>(); it != b.template end<rm>(); ++it)
@@ -635,9 +663,9 @@ namespace xt
                 ++e_iter;
             }
             EXPECT_TRUE(e_iter == exp_iter.end());
-       }
+        }
 
-       {
+        {
             std::vector<double> exp_iter = {1, 2, 3, 1, 2, 3};
             auto e_iter = exp_iter.begin();
             for (auto it = b.template begin<cm>(); it != b.template end<cm>(); ++it)
@@ -646,6 +674,6 @@ namespace xt
                 ++e_iter;
             }
             EXPECT_TRUE(e_iter == exp_iter.end());
-       }
+        }
     }
 }
