@@ -149,7 +149,8 @@ namespace xt
     {
         xarray_optional<int> a = {
             {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
-            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}};
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
         a(1, 0, 1).has_value() = false;
         a(1, 2, 3).has_value() = false;
 
@@ -181,7 +182,8 @@ namespace xt
     {
         xarray_optional<int> a = {
             {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
-            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}};
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
 
         a(1, 0, 1).has_value() = false;
         a(1, 2, 3).has_value() = false;
@@ -373,7 +375,8 @@ namespace xt
     {
         xarray_optional<int> a = {
             {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
-            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}};
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
         a(1, 0, 1).has_value() = false;
         a(1, 2, 3).has_value() = false;
 
@@ -400,7 +403,8 @@ namespace xt
     {
         xarray_optional<int> a = {
             {{0, 1, 2, 3}, {4, 5, 6, 7}, {8, 9, 10, 11}},
-            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}};
+            {{12, 13, 14, 15}, {16, 17, 18, 19}, {20, 21, 22, 23}}
+        };
         a(1, 0, 1).has_value() = false;
         a(1, 2, 3).has_value() = false;
 
