@@ -1,46 +1,47 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
-
-#include "gtest/gtest.h"
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #include "xtensor/xarray.hpp"
 #include "xtensor/xio.hpp"
 #include "xtensor/xoptional_assembly.hpp"
 
 #include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
     using array_type = xarray<int>;
     using flag_array_type = xarray<bool>;
     using opt_ass_type = xoptional_assembly<array_type, flag_array_type>;
-    using cm_opt_ass_type = xoptional_assembly<xarray<int, layout_type::column_major>, xarray<bool, layout_type::column_major>>;
+    using cm_opt_ass_type = xoptional_assembly<
+        xarray<int, layout_type::column_major>,
+        xarray<bool, layout_type::column_major>>;
     using dyn_opt_ass_type = xoptional_assembly<xarray<int, layout_type::dynamic>, xarray<bool, layout_type::dynamic>>;
 
     TEST(xoptional_assembly, shaped_constructor)
     {
+        SUBCASE("row_major constructor")
         {
-            SCOPED_TRACE("row_major constructor");
             row_major_result<> rm;
             dyn_opt_ass_type ra(rm.m_shape, layout_type::row_major);
             compare_shape(ra, rm);
         }
 
+        SUBCASE("column_major constructor")
         {
-            SCOPED_TRACE("column_major constructor");
             column_major_result<> cm;
             cm_opt_ass_type ca(cm.m_shape);
             compare_shape(ca, cm);
         }
 
+        SUBCASE("from shape")
         {
-            SCOPED_TRACE("from shape");
             std::array<std::size_t, 3> shp = {5, 4, 2};
             std::vector<std::size_t> shp_as_vec = {5, 4, 2};
             auto ca = cm_opt_ass_type::from_shape({3, 2, 1});
@@ -60,8 +61,8 @@ namespace xt
 
     TEST(xoptional_assembly, valued_constructor)
     {
+        SUBCASE("row_major valued constructor")
         {
-            SCOPED_TRACE("row_major valued constructor");
             row_major_result<> rm;
             int value = 2;
             dyn_opt_ass_type ra(rm.m_shape, value, layout_type::row_major);
@@ -70,8 +71,8 @@ namespace xt
             EXPECT_EQ(ra.value().storage(), vec);
         }
 
+        SUBCASE("column_major valued constructor")
         {
-            SCOPED_TRACE("column_major valued constructor");
             column_major_result<> cm;
             int value = 2;
             cm_opt_ass_type ca(cm.m_shape, value);
@@ -127,7 +128,7 @@ namespace xt
         EXPECT_EQ(a2(1, 0), opt(3, true));
         EXPECT_EQ(a2(1, 1), opt(4, true));
 
-        array_type value2 = { {1, 2}, {3, 4} };
+        array_type value2 = {{1, 2}, {3, 4}};
         opt_ass_type a3(std::move(value2));
         EXPECT_EQ(a3(0, 0), opt(1, true));
         EXPECT_EQ(a3(0, 1), opt(2, true));
@@ -141,15 +142,15 @@ namespace xt
         int value = 2;
         dyn_opt_ass_type a(res.m_shape, res.m_strides, value);
 
+        SUBCASE("copy constructor")
         {
-            SCOPED_TRACE("copy constructor");
             dyn_opt_ass_type b(a);
             compare_shape(a, b);
             EXPECT_EQ(a.storage(), b.storage());
         }
 
+        SUBCASE("assignment operator")
         {
-            SCOPED_TRACE("assignment operator");
             row_major_result<> r;
             dyn_opt_ass_type c(r.m_shape, dyn_opt_ass_type::value_type(0, false));
             EXPECT_NE(a.storage(), c.storage());
@@ -165,16 +166,16 @@ namespace xt
         int value = 2;
         dyn_opt_ass_type a(res.m_shape, res.m_strides, value);
 
+        SUBCASE("move constructor")
         {
-            SCOPED_TRACE("move constructor");
             dyn_opt_ass_type tmp(a);
             dyn_opt_ass_type b(std::move(tmp));
             compare_shape(a, b);
             EXPECT_EQ(a.storage(), b.storage());
         }
 
+        SUBCASE("move assignment")
         {
-            SCOPED_TRACE("move assignment");
             row_major_result<> r;
             dyn_opt_ass_type c(r.m_shape, dyn_opt_ass_type::value_type(0, false));
             EXPECT_NE(a.value().storage(), c.value().storage());
@@ -229,7 +230,7 @@ namespace xt
     TEST(xoptional_assembly, unchecked)
     {
         using opt = xtl::xoptional<int>;
-        opt_ass_type a = { { opt(1), opt(2, false) },{ opt(3, false), opt(4) } };
+        opt_ass_type a = {{opt(1), opt(2, false)}, {opt(3, false), opt(4)}};
         EXPECT_EQ(a.unchecked(0, 0), opt(1, true));
         EXPECT_EQ(a.unchecked(0, 1), opt(2, false));
         EXPECT_EQ(a.unchecked(1, 0), opt(3, false));
@@ -280,16 +281,16 @@ namespace xt
         shape_type s = {3, 1, 4, 2};
         opt_ass_type vec(s);
 
+        SUBCASE("same shape")
         {
-            SCOPED_TRACE("same shape");
             shape_type s1 = s;
             bool res = vec.broadcast_shape(s1);
             EXPECT_EQ(s1, s);
             EXPECT_TRUE(res);
         }
 
+        SUBCASE("different shape")
         {
-            SCOPED_TRACE("different shape");
             shape_type s2 = {3, 5, 1, 2};
             shape_type s2r = {3, 5, 4, 2};
             bool res = vec.broadcast_shape(s2);
@@ -297,16 +298,16 @@ namespace xt
             EXPECT_FALSE(res);
         }
 
+        SUBCASE("incompatible shapes")
         {
-            SCOPED_TRACE("incompatible shapes");
             shape_type s4 = {2, 1, 3, 2};
             XT_EXPECT_THROW(vec.broadcast_shape(s4), broadcast_error);
         }
 
         {
             shape_type s2 = {3, 1, 4, 2};
+            SUBCASE("different dimensions")
             vec.resize(s2);
-            SCOPED_TRACE("different dimensions");
             shape_type s3 = {5, 3, 1, 4, 2};
             shape_type s3r = s3;
             bool res = vec.broadcast_shape(s3);
@@ -320,26 +321,34 @@ namespace xt
         using opt = xtl::xoptional<int>;
         std::vector<opt> vec = {opt(1), opt(2, false), opt(3, false), opt(4)};
 
+        SUBCASE("row_major storage iterator")
         {
-            SCOPED_TRACE("row_major storage iterator");
             opt_ass_type rma(opt_ass_type::shape_type({2, 2}));
             std::copy(vec.cbegin(), vec.cend(), rma.begin<layout_type::row_major>());
             EXPECT_EQ(vec[0], rma(0, 0));
             EXPECT_EQ(vec[1], rma(0, 1));
             EXPECT_EQ(vec[2], rma(1, 0));
             EXPECT_EQ(vec[3], rma(1, 1));
-            EXPECT_EQ(vec.size(), std::size_t(std::distance(rma.begin<layout_type::row_major>(), rma.end<layout_type::row_major>())));
+            EXPECT_EQ(
+                vec.size(),
+                std::size_t(std::distance(rma.begin<layout_type::row_major>(), rma.end<layout_type::row_major>()))
+            );
         }
 
+        SUBCASE("column_major storage iterator")
         {
-            SCOPED_TRACE("column_major storage iterator");
             cm_opt_ass_type cma(opt_ass_type::shape_type({2, 2}));
             std::copy(vec.cbegin(), vec.cend(), cma.begin<layout_type::column_major>());
             EXPECT_EQ(vec[0], cma(0, 0));
             EXPECT_EQ(vec[1], cma(1, 0));
             EXPECT_EQ(vec[2], cma(0, 1));
             EXPECT_EQ(vec[3], cma(1, 1));
-            EXPECT_EQ(vec.size(), std::size_t(std::distance(cma.begin<layout_type::column_major>(), cma.end<layout_type::column_major>())));
+            EXPECT_EQ(
+                vec.size(),
+                std::size_t(
+                    std::distance(cma.begin<layout_type::column_major>(), cma.end<layout_type::column_major>())
+                )
+            );
         }
     }
 
@@ -493,12 +502,18 @@ namespace xt
 
     TEST(xoptional_assembly, mixed_semantic)
     {
-        using d_opt_ass_type = xoptional_assembly<xarray<double, layout_type::row_major>, xarray<bool, layout_type::row_major>>;
+        using d_opt_ass_type = xoptional_assembly<
+            xarray<double, layout_type::row_major>,
+            xarray<bool, layout_type::row_major>>;
         using opt = xtl::xoptional<double>;
-        d_opt_ass_type a = {{opt(1.), opt(2., false), opt(3., false), opt(4.)},
-                            {opt(5., false), opt(6.), opt(7.), opt(8., false)}};
-        xarray_optional<double> b = {{opt(1.), opt(2.), opt(3., false), opt(4., false)},
-                                     {opt(5., false), opt(6.), opt(7.), opt(8.)}};
+        d_opt_ass_type a = {
+            {opt(1.), opt(2., false), opt(3., false), opt(4.)},
+            {opt(5., false), opt(6.), opt(7.), opt(8., false)}
+        };
+        xarray_optional<double> b = {
+            {opt(1.), opt(2.), opt(3., false), opt(4., false)},
+            {opt(5., false), opt(6.), opt(7.), opt(8.)}
+        };
 
         d_opt_ass_type res = a + b;
         EXPECT_EQ(res(0, 0), opt(2.));
@@ -514,13 +529,17 @@ namespace xt
     TEST(xoptional_assembly, mixed_expression)
     {
         using opt = xtl::xoptional<int>;
-        dyn_opt_ass_type a = { { opt(1), opt(2, false), opt(3, false), opt(4) },
-                               { opt(5, false), opt(6), opt(7), opt(8, false) } };
-        xarray<int> b = { { 1, 2, 3, 4}, { 5, 6, 7, 8} };
+        dyn_opt_ass_type a = {
+            {opt(1), opt(2, false), opt(3, false), opt(4)},
+            {opt(5, false), opt(6), opt(7), opt(8, false)}
+        };
+        xarray<int> b = {{1, 2, 3, 4}, {5, 6, 7, 8}};
 
         dyn_opt_ass_type c = a + b;
-        dyn_opt_ass_type res = { { opt(2), opt(4, false), opt(6, false), opt(8) },
-                                 { opt(10, false), opt(12), opt(14), opt(16, false) } };
+        dyn_opt_ass_type res = {
+            {opt(2), opt(4, false), opt(6, false), opt(8)},
+            {opt(10, false), opt(12), opt(14), opt(16, false)}
+        };
         EXPECT_EQ(res, c);
 
         dyn_opt_ass_type d = 2 * a;
