@@ -1,19 +1,18 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
-
-#include "test_common_macros.hpp"
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #include "xtensor/xarray.hpp"
 #include "xtensor/xio.hpp"
 #include "xtensor/xoptional_assembly.hpp"
 
 #include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -139,8 +138,7 @@ namespace xt
         array_type v = {{1, 2, 3}, {4, 5, 6}};
         flag_array_type hv = {{true, false, true}, {false, true, false}};
         adaptor_type a(v, hv);
-        std::vector<std::size_t> v00({0, 0}), v01({0, 1}), v02({0, 2}),
-            v10({1, 0}), v11({1, 1}), v12({1, 2});
+        std::vector<std::size_t> v00({0, 0}), v01({0, 1}), v02({0, 2}), v10({1, 0}), v11({1, 1}), v12({1, 2});
 
         EXPECT_EQ(a.element(v00.begin(), v00.end()), opt(1, true));
         EXPECT_EQ(a.element(v01.begin(), v01.end()), opt(2, false));
@@ -156,8 +154,7 @@ namespace xt
         array_type v = {{1, 2, 3}, {4, 5, 6}};
         flag_array_type hv = {{true, false, true}, {false, true, false}};
         adaptor_type a(v, hv);
-        xindex i00({0, 0}), i01({0, 1}), i02({0, 2}),
-            i10({1, 0}), i11({1, 1}), i12({1, 2});
+        xindex i00({0, 0}), i01({0, 1}), i02({0, 2}), i10({1, 0}), i11({1, 1}), i12({1, 2});
 
         EXPECT_EQ(a[i00], opt(1, true));
         EXPECT_EQ((a[{0, 0}]), opt(1, true));
@@ -206,7 +203,7 @@ namespace xt
 
         {
             shape_type s2 = {3, 1, 4, 2};
-        SUBCASE("different dimensions")
+            SUBCASE("different dimensions")
             a.resize(s2);
             shape_type s3 = {5, 3, 1, 4, 2};
             shape_type s3r = s3;
@@ -232,7 +229,10 @@ namespace xt
             EXPECT_EQ(vec[1], rma(0, 1));
             EXPECT_EQ(vec[2], rma(1, 0));
             EXPECT_EQ(vec[3], rma(1, 1));
-            EXPECT_EQ(vec.size(), std::size_t(std::distance(rma.begin<layout_type::row_major>(), rma.end<layout_type::row_major>())));
+            EXPECT_EQ(
+                vec.size(),
+                std::size_t(std::distance(rma.begin<layout_type::row_major>(), rma.end<layout_type::row_major>()))
+            );
         }
 
         SUBCASE("column_major storage iterator")
@@ -246,7 +246,12 @@ namespace xt
             EXPECT_EQ(vec[1], cma(1, 0));
             EXPECT_EQ(vec[2], cma(0, 1));
             EXPECT_EQ(vec[3], cma(1, 1));
-            EXPECT_EQ(vec.size(), std::size_t(std::distance(cma.begin<layout_type::column_major>(), cma.end<layout_type::column_major>())));
+            EXPECT_EQ(
+                vec.size(),
+                std::size_t(
+                    std::distance(cma.begin<layout_type::column_major>(), cma.end<layout_type::column_major>())
+                )
+            );
         }
     }
 
