@@ -27,7 +27,8 @@ namespace xt
             {0, 0, 0, 0, 1, 2, 0, 0, 0},
             {0, 0, 0, 3, 4, 5, 0, 0, 0},
             {0, 0, 0, 0, 0, 0, 0, 0, 0},
-            {0, 0, 0, 0, 0, 0, 0, 0, 0}};
+            {0, 0, 0, 0, 0, 0, 0, 0, 0}
+        };
 
         xt::xtensor<size_t, 2> c = xt::pad(a, {{2, 2}, {3, 3}}, xt::pad_mode::constant);
 
@@ -77,7 +78,8 @@ namespace xt
             {0, 0, 0, 0, 1, 2, 2, 2, 2},
             {3, 3, 3, 3, 4, 5, 5, 5, 5},
             {3, 3, 3, 3, 4, 5, 5, 5, 5},
-            {3, 3, 3, 3, 4, 5, 5, 5, 5}};
+            {3, 3, 3, 3, 4, 5, 5, 5, 5}
+        };
 
         xt::xtensor<size_t, 2> c = xt::pad(a, {{2, 2}, {3, 3}}, xt::pad_mode::edge);
 
@@ -127,7 +129,8 @@ namespace xt
             {0, 1, 2, 0, 1, 2, 0, 1, 2},
             {3, 4, 5, 3, 4, 5, 3, 4, 5},
             {0, 1, 2, 0, 1, 2, 0, 1, 2},
-            {3, 4, 5, 3, 4, 5, 3, 4, 5}};
+            {3, 4, 5, 3, 4, 5, 3, 4, 5}
+        };
 
         xt::xtensor<size_t, 2> c = xt::pad(a, {{2, 2}, {3, 3}}, xt::pad_mode::wrap);
 
@@ -177,7 +180,8 @@ namespace xt
             {2, 1, 0, 0, 1, 2, 2, 1, 0},
             {5, 4, 3, 3, 4, 5, 5, 4, 3},
             {5, 4, 3, 3, 4, 5, 5, 4, 3},
-            {2, 1, 0, 0, 1, 2, 2, 1, 0}};
+            {2, 1, 0, 0, 1, 2, 2, 1, 0}
+        };
 
         xt::xtensor<size_t, 2> c = xt::pad(a, {{2, 2}, {3, 3}}, xt::pad_mode::symmetric);
 
@@ -221,11 +225,8 @@ namespace xt
     {
         xt::xtensor<size_t, 2> a = {{0, 1, 2}, {3, 4, 5}};
 
-        xt::xtensor<size_t, 2> b = {
-            {5, 4, 3, 4, 5, 4, 3},
-            {2, 1, 0, 1, 2, 1, 0},
-            {5, 4, 3, 4, 5, 4, 3},
-            {2, 1, 0, 1, 2, 1, 0}};
+        xt::xtensor<size_t, 2> b =
+            {{5, 4, 3, 4, 5, 4, 3}, {2, 1, 0, 1, 2, 1, 0}, {5, 4, 3, 4, 5, 4, 3}, {2, 1, 0, 1, 2, 1, 0}};
 
         xt::xtensor<size_t, 2> c = xt::pad(a, {{1, 1}, {2, 2}}, xt::pad_mode::reflect);
 
@@ -300,7 +301,8 @@ namespace xt
             {4, 5, 4, 5, 4, 5, 4, 5},
             {0, 1, 0, 1, 0, 1, 0, 1},
             {2, 3, 2, 3, 2, 3, 2, 3},
-            {4, 5, 4, 5, 4, 5, 4, 5}};
+            {4, 5, 4, 5, 4, 5, 4, 5}
+        };
 
         xt::xtensor<size_t, 2> c = xt::tile(a, {3u, 4u});
 
@@ -320,7 +322,8 @@ namespace xt
             {4, 5, 4, 5, 4, 5, 4, 5},
             {0, 1, 0, 1, 0, 1, 0, 1},
             {2, 3, 2, 3, 2, 3, 2, 3},
-            {4, 5, 4, 5, 4, 5, 4, 5}};
+            {4, 5, 4, 5, 4, 5, 4, 5}
+        };
 
         xt::xtensor<size_t, 2> c = xt::tile(a, std::array<size_t, 2>{{3u, 4u}});
 
@@ -340,7 +343,8 @@ namespace xt
             {4, 5, 4, 5, 4, 5, 4, 5},
             {0, 1, 0, 1, 0, 1, 0, 1},
             {2, 3, 2, 3, 2, 3, 2, 3},
-            {4, 5, 4, 5, 4, 5, 4, 5}};
+            {4, 5, 4, 5, 4, 5, 4, 5}
+        };
 
         xt::xtensor<size_t, 2> c = xt::tile(a, std::vector<size_t>{{3u, 4u}});
 
@@ -353,7 +357,8 @@ namespace xt
         xt::xarray<double> expected = {
             {{1., 0., 0., 0.}, {0., 1., 0., 0.}, {0., 0., 1., 0.}, {0., 0., 0., 1.}},
             {{1., 0., 0., 0.}, {0., 1., 0., 0.}, {0., 0., 1., 0.}, {0., 0., 0., 1.}},
-            {{1., 0., 0., 0.}, {0., 1., 0., 0.}, {0., 0., 1., 0.}, {0., 0., 0., 1.}}};
+            {{1., 0., 0., 0.}, {0., 1., 0., 0.}, {0., 0., 1., 0.}, {0., 0., 0., 1.}}
+        };
         EXPECT_EQ(m, expected);
     }
 }
