@@ -1,19 +1,20 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
-#include "test_common_macros.hpp"
-#include "xtensor/xtensor.hpp"
-#include "xtensor/xarray.hpp"
-#include "test_common.hpp"
 #include <type_traits>
 
+#include "xtensor/xarray.hpp"
 #include "xtensor/xio.hpp"
+#include "xtensor/xtensor.hpp"
+
+#include "test_common.hpp"
+#include "test_common_macros.hpp"
 
 namespace xt
 {
@@ -30,13 +31,7 @@ namespace xt
 
     TEST(xtensor, initializer_constructor)
     {
-        xtensor_dynamic t
-          {{{0, 1, 2},
-            {3, 4, 5},
-            {6, 7, 8}},
-           {{9, 10, 11},
-            {12, 13, 14},
-            {15, 16, 17}}};
+        xtensor_dynamic t{{{0, 1, 2}, {3, 4, 5}, {6, 7, 8}}, {{9, 10, 11}, {12, 13, 14}, {15, 16, 17}}};
         EXPECT_EQ(t.dimension(), size_t(3));
         EXPECT_EQ(t(0, 0, 1), 1);
         EXPECT_EQ(t.shape()[0], size_t(2));
@@ -169,10 +164,7 @@ namespace xt
 
     TEST(xtensor, missing)
     {
-        xt::xtensor<int, 2> a
-           {{0, 1, 2},
-            {3, 4, 5},
-            {6, 7, 8}};
+        xt::xtensor<int, 2> a{{0, 1, 2}, {3, 4, 5}, {6, 7, 8}};
 
         EXPECT_EQ(a(0), 0);
         EXPECT_EQ(a(1), 1);
@@ -224,7 +216,7 @@ namespace xt
 
 #ifdef XTENSOR_ENABLE_ASSERT
         xtensor_dynamic b;
-        std::vector<size_t> s = { 2u, 2u };
+        std::vector<size_t> s = {2u, 2u};
         xtensor_dynamic::strides_type strides = {2u, 1u};
         EXPECT_THROW(b.resize(s), std::runtime_error);
         EXPECT_THROW(b.resize(s, layout_type::dynamic), std::runtime_error);
@@ -327,18 +319,24 @@ namespace xt
         EXPECT_EQ(2, res(0));
         EXPECT_EQ(2, res(1));
 
-        xtensor<int, 1> b = { 1, 2 };
+        xtensor<int, 1> b = {1, 2};
         xt::xarray<double> ca = a * b;
     }
 
     TEST(xtensor, move_from_xarray)
     {
-        xarray<double> a = {{{1,2,3}, {4,5,6}}, {{10, 10, 10}, {1,5,10}}};
+        xarray<double> a = {{{1, 2, 3}, {4, 5, 6}}, {{10, 10, 10}, {1, 5, 10}}};
         xarray<double> a1 = a;
         xtensor<double, 3> b(std::move(a1));
         EXPECT_EQ(a, b);
-        EXPECT_TRUE(std::equal(a.strides().begin(), a.strides().end(), b.strides().begin()) && a.strides().size() == b.strides().size());
-        EXPECT_TRUE(std::equal(a.backstrides().begin(), a.backstrides().end(), b.backstrides().begin()) && a.backstrides().size() == b.backstrides().size());
+        EXPECT_TRUE(
+            std::equal(a.strides().begin(), a.strides().end(), b.strides().begin())
+            && a.strides().size() == b.strides().size()
+        );
+        EXPECT_TRUE(
+            std::equal(a.backstrides().begin(), a.backstrides().end(), b.backstrides().begin())
+            && a.backstrides().size() == b.backstrides().size()
+        );
         EXPECT_EQ(a.layout(), b.layout());
 
         xarray<double> a2 = a;
@@ -346,51 +344,61 @@ namespace xt
         c = std::move(a2);
 
         EXPECT_EQ(a, c);
-        EXPECT_TRUE(std::equal(a.strides().begin(), a.strides().end(), c.strides().begin()) && a.strides().size() == c.strides().size());
-        EXPECT_TRUE(std::equal(a.backstrides().begin(), a.backstrides().end(), c.backstrides().begin()) && a.backstrides().size() == c.backstrides().size());
+        EXPECT_TRUE(
+            std::equal(a.strides().begin(), a.strides().end(), c.strides().begin())
+            && a.strides().size() == c.strides().size()
+        );
+        EXPECT_TRUE(
+            std::equal(a.backstrides().begin(), a.backstrides().end(), c.backstrides().begin())
+            && a.backstrides().size() == c.backstrides().size()
+        );
         EXPECT_EQ(a.layout(), c.layout());
     }
 
     TEST(xtensor, from_indices)
     {
-        xt::xtensor<int, 2> a = {{1,0,0},{1,1,0},{1,1,1}};
-        xt::xtensor<size_t, 2> jdx = {{0,0},{1,0},{1,1},{2,0},{2,1},{2,2}};
-        xt::xtensor<size_t, 2> idx = xt::from_indices(xt::argwhere(xt::equal(a,1)));
-        EXPECT_TRUE(idx==jdx);
+        xt::xtensor<int, 2> a = {{1, 0, 0}, {1, 1, 0}, {1, 1, 1}};
+        xt::xtensor<size_t, 2> jdx = {{0, 0}, {1, 0}, {1, 1}, {2, 0}, {2, 1}, {2, 2}};
+        xt::xtensor<size_t, 2> idx = xt::from_indices(xt::argwhere(xt::equal(a, 1)));
+        EXPECT_TRUE(idx == jdx);
     }
 
     TEST(xtensor, flatten_indices)
     {
-        xt::xtensor<int, 1> a = {1,0,0,1,1,0,1,1,1};
-        xt::xtensor<size_t, 1> jdx = {0,3,4,6,7,8};
-        xt::xtensor<size_t, 1> idx = xt::flatten_indices(xt::argwhere(xt::equal(a,1)));
-        EXPECT_TRUE(idx==jdx);
+        xt::xtensor<int, 1> a = {1, 0, 0, 1, 1, 0, 1, 1, 1};
+        xt::xtensor<size_t, 1> jdx = {0, 3, 4, 6, 7, 8};
+        xt::xtensor<size_t, 1> idx = xt::flatten_indices(xt::argwhere(xt::equal(a, 1)));
+        EXPECT_TRUE(idx == jdx);
     }
 
     TEST(xtensor, ravel_indices)
     {
-        xt::xtensor<int, 2> a = {{1,0,0},{1,1,0},{1,1,1}};
-        xt::xtensor<size_t, 1> jdx = {0,3,4,6,7,8};
-        xt::xtensor<size_t, 1> idx = xt::ravel_indices(xt::argwhere(xt::equal(a,1)), a.shape());
-        EXPECT_TRUE(idx==jdx);
+        xt::xtensor<int, 2> a = {{1, 0, 0}, {1, 1, 0}, {1, 1, 1}};
+        xt::xtensor<size_t, 1> jdx = {0, 3, 4, 6, 7, 8};
+        xt::xtensor<size_t, 1> idx = xt::ravel_indices(xt::argwhere(xt::equal(a, 1)), a.shape());
+        EXPECT_TRUE(idx == jdx);
     }
 
     TEST(xtensor, ravel_indices_column_major)
     {
-        xt::xtensor<int, 2, xt::layout_type::column_major> a = {{1,0,0},{1,1,0},{1,1,1}};
-        xt::xtensor<size_t, 1> jdx = {0,1,4,2,5,8};
-        xt::xtensor<size_t, 1> idx = xt::ravel_indices(xt::argwhere(xt::equal(a,1)), a.shape(), xt::layout_type::column_major);
-        EXPECT_TRUE(idx==jdx);
+        xt::xtensor<int, 2, xt::layout_type::column_major> a = {{1, 0, 0}, {1, 1, 0}, {1, 1, 1}};
+        xt::xtensor<size_t, 1> jdx = {0, 1, 4, 2, 5, 8};
+        xt::xtensor<size_t, 1> idx = xt::ravel_indices(
+            xt::argwhere(xt::equal(a, 1)),
+            a.shape(),
+            xt::layout_type::column_major
+        );
+        EXPECT_TRUE(idx == jdx);
     }
 
     TEST(xarray, operator_brace)
     {
 #ifdef XTENSOR_ENABLE_ASSERT
-        xt::xtensor<size_t, 2> a = {{0,1,2}, {3,4,5}};
+        xt::xtensor<size_t, 2> a = {{0, 1, 2}, {3, 4, 5}};
         EXPECT_THROW(a(2, 0), std::runtime_error);
         EXPECT_THROW(a(0, 3), std::runtime_error);
 
-        xt::xtensor<size_t, 2> b = {{0,1,2}};
+        xt::xtensor<size_t, 2> b = {{0, 1, 2}};
         EXPECT_THROW(a(0, 3), std::runtime_error);
         EXPECT_THROW(a(1, 3), std::runtime_error);
 #endif
@@ -398,19 +406,19 @@ namespace xt
 
     TEST(xtensor, periodic)
     {
-        xt::xtensor<size_t,2> a = {{0,1,2}, {3,4,5}};
-        xt::xtensor<size_t,2> b = {{0,1,2}, {30,40,50}};
-        a.periodic(-1,3) = 30;
-        a.periodic(-1,4) = 40;
-        a.periodic(-1,5) = 50;
+        xt::xtensor<size_t, 2> a = {{0, 1, 2}, {3, 4, 5}};
+        xt::xtensor<size_t, 2> b = {{0, 1, 2}, {30, 40, 50}};
+        a.periodic(-1, 3) = 30;
+        a.periodic(-1, 4) = 40;
+        a.periodic(-1, 5) = 50;
         EXPECT_EQ(a, b);
     }
 
     TEST(xtensor, flat)
     {
         {
-            xt::xtensor<size_t, 2, xt::layout_type::row_major> a = {{0,1,2}, {3,4,5}};
-            xt::xtensor<size_t, 2, xt::layout_type::row_major> b = {{0,1,2}, {30,40,50}};
+            xt::xtensor<size_t, 2, xt::layout_type::row_major> a = {{0, 1, 2}, {3, 4, 5}};
+            xt::xtensor<size_t, 2, xt::layout_type::row_major> b = {{0, 1, 2}, {30, 40, 50}};
             a.flat(3) = 30;
             a.flat(4) = 40;
             a.flat(5) = 50;
@@ -420,8 +428,8 @@ namespace xt
 #endif
         }
         {
-            xt::xtensor<size_t, 2, xt::layout_type::column_major> a = {{0,1,2}, {3,4,5}};
-            xt::xtensor<size_t, 2, xt::layout_type::column_major> b = {{0,1,2}, {30,40,50}};
+            xt::xtensor<size_t, 2, xt::layout_type::column_major> a = {{0, 1, 2}, {3, 4, 5}};
+            xt::xtensor<size_t, 2, xt::layout_type::column_major> b = {{0, 1, 2}, {30, 40, 50}};
             a.flat(1) = 30;
             a.flat(3) = 40;
             a.flat(5) = 50;
@@ -434,9 +442,9 @@ namespace xt
 
     TEST(xtensor, in_bounds)
     {
-        xt::xtensor<size_t,2> a = {{0,1,2}, {3,4,5}};
-        EXPECT_TRUE(a.in_bounds(0,0) == true);
-        EXPECT_TRUE(a.in_bounds(2,0) == false);
+        xt::xtensor<size_t, 2> a = {{0, 1, 2}, {3, 4, 5}};
+        EXPECT_TRUE(a.in_bounds(0, 0) == true);
+        EXPECT_TRUE(a.in_bounds(2, 0) == false);
     }
 
     TEST(xtensor, iterator_types)
